library(readxl)
library(dplyr)
# set working directory to current directory
dataset <- read_excel("AER papers with IV estimates since 2014.xlsx")
View(dataset)

#####
# functions
perc <- function(x) {
  return(paste(round(100*x,digits=2),"%",sep=""))
}

# total number of IV specification
sum(dataset$`Any linear IV estimates`==1)
# total number of articles that mention instrumental variable in the abstract
length(unique(c(dataset$Title)))

# from now on, subset to specifications that contain IV estimates
dataset <- dataset[dataset$`Any linear IV estimates`==1,]

# number of linear IV specifications with p = 1
sum(dataset$`Number of endogenous variables`==1)
#   number of linear IV specifications with k = 1
sum(dataset$`Number of instruments`==1)
# total number of linear IV papers
length(unique(dataset$Title))
# total number of first-stage
length(unique(c(dataset$Title,dataset$`First stage specification`)))

# number of specifications per article (stored in n of dataframe n)
n_by_article <- as.data.frame(dataset$Title)
n <- n_by_article  %>% 
  add_count(dataset$Title)
write.table(cbind(count(dataset,dataset$Issue,dataset$Title,dataset$`public replication files`)),
            "articles.csv",sep=",")

#Summary statistics on distribution of p
#####

sort(unique(dataset$`Number of endogenous variables`))
for (ii in 1:4) {
  data<-dataset$`Number of instruments`[dataset$`Number of endogenous variables`==ii]
  nspec<- n$n[dataset$`Number of endogenous variables`==ii]
 
  write.table(cbind(ii,length(data),
                    perc(mean(data==ii)),
                    perc((1-mean(data==ii))),
                    round(mean(data[data>ii]),digits=2)),
   "p dist unweighted.csv",row.names=F,col.names=F,append=T,sep=",")
                           
 
  write.table(cbind(ii,round(sum(1/nspec),digits=2),
                           perc(weighted.mean(data==ii,w=1/nspec)),
                           perc((1-weighted.mean(data==ii,w=1/nspec))),
                    round(weighted.mean(data[data>ii], w=1/nspec[data>ii]),digits=2))
                     ,
              "p dist weighted.csv",row.names=F,col.names=F,append=T,sep=",")
}

#Summary statistics on distribution of F for specifications with p == 1
#####

k<-sort(unique(
  dataset$`Number of instruments`[dataset$`Number of endogenous variables`==1]))
SYcutoffs <- c(8.96, 11.59, 12.83, 27.99, 33.97, 36.37, 42.37, 44.78, 44.78 )
# summary F for all specifications with p == 1, unweighted
data <- dataset[dataset$`Number of endogenous variables`==1, ]
perc(mean(data$`Any first-stage F reported` ))
mean(as.numeric(data$`first-stage F statistic`[data$`Any first-stage F reported` == 1]))
perc(mean(as.numeric(data$`first-stage F statistic`[data$`Any first-stage F reported` == 1])>10))
perc(mean(data$`Any weak-IV-robust result`))

mean(as.numeric(data$`first-stage F statistic`[data$`Any first-stage F reported` == 1 &
                                                 data$`Any weak-IV-robust result` == 1]))

# summary F for all specifications with p == 1, weighted
nspec <- n$n[dataset$`Number of endogenous variables`==1]
data <- cbind(data,nspec)
perc(weighted.mean(data$`Any first-stage F reported`,
      w=1/nspec))
weighted.mean(as.numeric(data$`first-stage F statistic`[data$`Any first-stage F reported` == 1 ]),
              w=1/data$nspec[data$`Any first-stage F reported` == 1])

perc(weighted.mean(as.numeric(data$`first-stage F statistic`[data$`Any first-stage F reported` == 1])>10,
              w=1/data$nspec[data$`Any first-stage F reported` == 1]))

perc(weighted.mean(data$`Any weak-IV-robust result`,
              w=1/data$nspec))

weighted.mean(as.numeric(dataset$`first-stage F statistic`[dataset$`Any first-stage F reported` == 1 &
                                                             dataset$`Number of endogenous variables`==1 &
                                                             dataset$`Any weak-IV-robust result` == 1]),
              w=1/n$n[dataset$`Any first-stage F reported` == 1 &
                        dataset$`Number of endogenous variables`==1 &
                        dataset$`Any weak-IV-robust result` == 1])



for (ii in c(1,2,3,16,21,23,28,59,100)) {
  
  data<-dataset$`Any first-stage F reported`[dataset$`Number of instruments`==ii 
                                             &
                                               dataset$`Number of endogenous variables`==1 ]
  #print(c(length(data),mean(data)))
  nspec<- n$n[dataset$`Number of instruments`==ii&
                dataset$`Number of endogenous variables`==1 ] 

 print(c(sum(1/nspec),weighted.mean(data,w=1/nspec)))

  
  data<-as.numeric(dataset$`first-stage F statistic`[dataset$`Number of endogenous variables`==1 & 
                                                       dataset$`Number of instruments`==ii 
                                          & dataset$`Any first-stage F reported`==1])
  robust<-dataset$`Any weak-IV-robust result`[dataset$`Number of endogenous variables`==1 & 
                                                       dataset$`Number of instruments`==ii 
                                                     & dataset$`Any first-stage F reported`==1]
  nspec<- n$n[dataset$`Number of endogenous variables`==1 & 
                dataset$`Number of instruments`==ii 
              & dataset$`Any first-stage F reported`==1] 
  nspec_robust <- n$n[dataset$`Number of endogenous variables`==1& 
                                       dataset$`Number of instruments`==ii]
 # write.table(format(cbind(mean(data),100*mean(data>10),
  #        100*mean(data>SYcutoffs[k==ii]),SYcutoffs[k==ii],
   #       100*mean(dataset$`Any weak-IV-robust result`[dataset$`Number of endogenous variables`==1& 
    #                                                     dataset$`Number of instruments`==ii])
     #     ,mean(data[robust==1])),digits=2, nsmall = 2), 
      #    "F stat unweighted.csv",row.names=F,col.names=F,append=T,sep=",",na=" ")
   #write.table(format(cbind(weighted.mean(data,w=1/nspec),100*weighted.mean(data>10,w=1/nspec),
    #      100*weighted.mean(data>SYcutoffs[k==ii],w=1/nspec),SYcutoffs[k==ii],
     #    100*weighted.mean(dataset$`Any weak-IV-robust result`[dataset$`Number of endogenous variables`==1& 
      #                                                 dataset$`Number of instruments`==ii],
       #                    w=1/nspec_robust)
       #,weighted.mean(data[robust==1],w=1/nspec[robust==1])),digits=2, nsmall = 2), 
      #"F stat unweighted.csv",row.names=F,col.names=F,append=T,sep=",",na=" ")

  
}

# number of papers with first-stage F reported
length(unique(dataset$Title[dataset$`Any first-stage F reported`==1]))

# total number of first-stage with F reported
length(unique(c(dataset$Title,dataset$`First stage specification`[dataset$`Any first-stage F reported`==1])))

# total number of specification with F reported
sum(dataset$`Any first-stage F reported`==1)

# total number of specifications with robust test
sum(dataset$`Any weak-IV-robust result`==1)

# total number of papers with replication datasets
length(unique(dataset$Title[dataset$`public replication files`==1]))
# total number of papers
length(unique(dataset$Title))

# total number of specifications with replication datasets
sum(dataset$`public replication files`==1)

# total number of specifications that are replicated/solved using delta method
sum(dataset$replicated==1|dataset$solved==1)

# total number of specifications that are not simulated due to singularities
sum(dataset$`replication error`==1)

# total number ofspecifications with reduced-form, first-stage, and IV estimates and standard errors
sum(rowSums(is.na(dataset[,
                   c("reduced-form standard error",
                     "First-stage standard errors  endo1",
                     "IV standard error")])) == 0)

# mean and sd of F
# mean k and p
mean(dataset$`Number of instruments`)
mean(dataset$`Number of endogenous variables`)

# subset that is just-identified
just <- dataset[dataset$replicated==1|dataset$solved==1,]
sum(just$`Any first-stage F reported`==1) # check how many have F statistics reported
nrow(just)
just <- just[just$`Number of instruments`==1,]
just$`IV standard error` <- as.numeric(just$`IV standard error`)
just$`IV coefficient` <- as.numeric(just$`IV coefficient`)

View(just)
crit = 1.96
ttest_length <- 2*crit*just$`IV standard error`
t_LL <- just$`IV coefficient`-crit*just$`IV standard error`
t_UL <- just$`IV coefficient`+crit*just$`IV standard error`

ttest_length_normalized <- mean(ttest_length/just$`IV standard error`)

a <- just$`replicated first-stage`^2-crit^2*just$`replicated first-stage variance`
b <- 2*crit^2*just$`replicated first-stage reduced-form covariance`-2*just$`replicated first-stage`*just$`replicated reduced-form`
c <- just$`replicated reduced-form`^2 - crit^2*just$`replicated reduced-form variance`
Delta <- b^2 - 4*a*c

  ar_UL <- (-b+sqrt(Delta))/(2*a)
  ar_LL <- (-b-sqrt(Delta))/(2*a)
  ar_CI <- paste("[",round(ar_LL,digits=2),",",round(ar_UL,digits=2),"]")
  
  ar_CI[a<0] <- paste("(-infty,",round(ar_LL[a<0],digits=2),"]U[",round(ar_UL[a<0],digits=2),",infty)")
 

ar_length = ar_UL-ar_LL
ar_length_normalized <- mean(na.omit((ar_UL-ar_LL)/just$`IV standard error`))

artest_0 <- just$`replicated reduced-form`^2 /just$`replicated reduced-form variance` > crit^2
ttest_0 <- abs(just$`IV coefficient`)/just$`IV standard error` > crit
mean(artest_0)
mean(ttest_0)
write.table(cbind(just$Issue,just$Title,just$`specification unique id`,just$`First stage specification`,
                  just$`IV specification (if reported in a different table than first stage)`,
                  just$`first-stage F statistic`,round(just$`replicated first-stage`^2/just$`replicated first-stage variance`,digits=2),
                  round(just$`IV coefficient`,digits = 2),round(just$`IV standard error`,digits=2),
                  just$`replicated first-stage`,just$`replicated first-stage variance`^0.5,
                  just$`replicated reduced-form`,just$`replicated reduced-form variance`^0.5,
                  ttest_0,ttest_length,t_LL, t_UL,
                  artest_0,ar_length,ar_LL,ar_UL,ar_CI),
            "just_id_t_ar_comparison.csv",row.names=FALSE,sep = ",")



 
