%% locate the files for each specification in the working directory
clear
filename = 'AER papers with IV estimates since 2014.xlsx'; % notes that xlsread trims trailing empty cells, which is why the first row is filled with 0's.
replicated = xlsread(filename,'AF:AF'); % replicated specifications with replication results saved in ./replication results/
solved = xlsread(filename,'AG:AG'); % solved for covariance within the spreadsheets
 
id_list = xlsread(filename,'A:A');
k_list = xlsread(filename,'G:G');
p_list = xlsread(filename,'H:H');
beta_null_list = xlsread(filename,'Y:Y');
 
vcov_list = xlsread(filename,'AH:AL');
% simulation set up
s=10000 ;
D=1000;
 

%% analyze specifications that we are able to replicate
id_list1 = id_list(replicated == 1);
k_list1 = k_list(replicated == 1);
p_list1 = p_list(replicated == 1);
beta_null_list1 = beta_null_list(replicated == 1);
  %%
 for i = 1:length(id_list1)

    disp(id_list1(i))
    spec = sprintf('%d',id_list1(i)); % convert the specification
    replication_filename = './replication results/'; % subdirectory that contains replication results
    
    b_filename = strcat(replication_filename,'b_', spec,'.txt');
    vcov_filename = strcat(replication_filename,'vcov_', spec,'.txt');

    b = readtable(b_filename,'Delimiter','\t');
    b(:,1) = []; %trim the table
    b(:,end) = [];
    vcov = readtable(vcov_filename,'Delimiter','\t');
    vcov(:,1) = [];
    vcov(:,end) = [];
    
    p=p_list1(i);
    k=k_list1(i);
    obs = obs_list1(i);

    %%
    pi = b{:,1:k};
    delta = b{:,(k+1):2*k};
 
    Sigma_pi = vcov{1:k,1:k};
    Sigma_delta = vcov{(k+1):(2*k),(k+1):(2*k)};
    Sigma_delta_pi = vcov{(k+1):(2*k),1:k};


    
    if k > 1
            zz_filename = strcat(replication_filename,'ZZ_', spec,'.txt');
            zz = readtable(zz_filename,'Delimiter','\t');
            zz(:,1) = [];
            zz(:,end) = [];
            zz = zz{1:k,1:k};
    else
            zz = 1;
    end
 
    beta_null = (pi*zz*pi')^-1*(pi*zz*delta');
 
    %%
  
        %to get critical values for effective F
        
    eff_f_crit = dlmread('olea_and_pflueger_eff_f_crit.txt',' ');
    simulation(s,k,spec,beta_null,pi,delta,Sigma_pi,Sigma_delta,Sigma_delta_pi,zz,eff_f_crit);

    simulation_bayes_eff_f(D,s,k,spec,beta_null,pi,delta,Sigma_pi,Sigma_delta,Sigma_delta_pi,zz,eff_f_crit);

    if k>1 
        
      simulation_overid(s,k,spec,beta_null,pi,delta,Sigma_pi,Sigma_delta,Sigma_delta_pi,zz);
    end
 

end

%% analyze specifications that we have to solve for covariance
 
id_list2 = id_list(solved == 1);

k_list2 = k_list(solved == 1);
p_list2 = p_list(solved == 1);
beta_null_list2 = beta_null_list(solved == 1);
vcov_list2 = vcov_list(solved == 1,:);
%%
for i = 1:length(id_list2)
%%
    disp(id_list2(i))
    spec = sprintf('%d',id_list2(i));
   
    p=p_list2(i);
    k=k_list2(i);
    % read in the replication results directly from the spreadsheet
    pi = vcov_list2(i,1);
    delta = vcov_list2(i,3);
 
    Sigma_pi = vcov_list2(i,2);
    Sigma_delta = vcov_list2(i,4);
    Sigma_delta_pi = vcov_list2(i,5);
    zz=1;

    beta_null = (pi*zz*pi')^-1*(pi*zz*delta');
 %%
    %to get critical values for effective F
    eff_f_crit = dlmread('olea_and_pflueger_eff_f_crit.txt',' ');
    simulation(s,k,spec,beta_null,pi,delta,Sigma_pi,Sigma_delta,Sigma_delta_pi,zz,eff_f_crit);

    simulation_bayes_eff_f(D,s,k,spec,beta_null,pi,delta,Sigma_pi,Sigma_delta,Sigma_delta_pi,zz,eff_f_crit);

 
end
 