/**********************************************************************************************
	* Replication code for "Credit Supply and the Price of Housing", American Economic Review
	*
	* Distributed under copyright, Giovanni Favara and Jean Imbs, 2014 and the American 
	* Economic Association, 2014
	*
	* This code creates Tables 1-6 and Figure 1-4 in the Paper, as well as Tables A1-A4 
	* in the Paper Appendix, and Tables OA2-OA8 in the on line web Appendix
	***********************************************************************************************/ 
	
	
	** Define working directory 
	clear all
	global 		main    "/cm/giovanni/Final_AER2"
	global 		data    "."
	global 		dofiles "$main/dofiles"
	global 		output  "$main/output"

	
	** load data 
	 
	use "$data/hmda.dta", clear
	merge 1:1 county year using "$data/hp_dereg_controls.dta", nogen keep(1 3)
	merge 1:1 county year using "$data/call.dta", nogen keep(1 3)
	
	** define controls 
	global D_control       "Dl_inc LDl_inc Dl_pop LDl_pop Dl_hpi LDl_hpi Dl_her_v LDl_her_v"
	global D_control_hp    "Dl_inc LDl_inc Dl_pop LDl_pop Dl_her_v LDl_her_v"
	global B_control        " etoa_b liatoa_b totltoa_b "
	
	capture program drop output_tables
program output_tables
	args  exexog1 exexogk specid 
{
	
	global exexog1 "`exexog1'" // first excluded exogenous variable
	global exexogk "`exexogk'" // last excluded exogenous variable
	 
	local b_fs_start = colnumb(suestb,"fs_mean:$exexog1")
	local b_fs_end = colnumb(suestb,"fs_mean:$exexogk")
	local b_rf_start = colnumb(suestb,"rf_mean:$exexog1")
	local b_rf_end = colnumb(suestb,"rf_mean:$exexogk")

	local vcov_fs_start = colnumb(suestV,"fs_mean:$exexog1")
	local vcov_fs_end = colnumb(suestV,"fs_mean:$exexogk")
	local vcov_rf_start = colnumb(suestV,"rf_mean:$exexog1")
	local vcov_rf_end = colnumb(suestV,"rf_mean:$exexogk")

	mat b_fs = suestb[1,`b_fs_start'..`b_fs_end']
	mat vcov_fs = suestV[`vcov_fs_start'..`vcov_fs_end',`vcov_fs_start'..`vcov_fs_end']
	mat b_rf = suestb[1,`b_rf_start'..`b_rf_end']
	mat vcov_rf = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_rf_start'..`vcov_rf_end']
	mat vcov_rf_fs = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_fs_start'..`vcov_fs_end']
 
	mat b = b_fs, b_rf
	mat list b // these would match the equation-by-equation regression results.
	mat2txt, matrix(b) saving(b_`specid') replace  // export with specification id

	mat vcov = vcov_fs, vcov_rf_fs' \ vcov_rf_fs , vcov_rf
	mat list vcov // these would match the equation-by-equation regression results.
	mat2txt, matrix(vcov) saving(vcov_`specid')  replace
 
}
end
	***********************************************************************************************
	**       TABLE   5         								     **
	***********************************************************************************************
	tab county, gen(county_)	 	
	** TABLE 5 (1)  
	xtivreg2 Dl_hpi (Dl_nloans_b = Linter_bra) LDl_hpi  $D_control_hp yryear_1994-yryear_2005 [aw=w1], fe   partial(yryear_1994-yryear_2005 )  first
	global G = e(N_g)
	gen fs_sample = e(sample)
	
	capture reghdfe Dl_nloans_b  Linter_bra  LDl_hpi  $D_control_hp    [aw=w1], absorb(yryear_1994-yryear_2005 county_1-county_1048)
	global N = e(N)
	global dof = (e(N)-1)/e(df_r)  
	

 
	foreach vv of varlist Dl_nloans_b Dl_vloans_b Dl_lir_b Linter_bra LDl_hpi  Dl_hpi  {
		//qui reg `vv' county_* [aw=w1] if fs_sample
		capture reghdfe `vv' $D_control_hp  if fs_sample==1  [aw=w1], absorb(yryear_1994-yryear_2005 county_1-county_1048)  residuals(`vv'_p)

	}
		 
 	qui sureg (fs_mean: Dl_nloans_b_p  Linter_bra_p LDl_hpi_p , nocons) ///
		(rf_mean:  Dl_hpi_p Linter_bra_p LDl_hpi_p  , nocons ) [aw=w1] if fs_sample  ==1  
	mat suestb = e(b)
	mat suestV = e(V)*$dof
 	
	global specid = 108
	dis $specid
	global exexog1 "Linter_bra_p"
	global exexogk "Linter_bra_p"
	qui output_tables $exexog1  $exexogk $specid
	
	** Table 5 (2)
	xtivreg2 Dl_hpi (Dl_vloans_b = Linter_bra) LDl_hpi  $D_control_hp yr* [aw=w1], fe   partial(yr*) first 
	drop fs_sample
	gen fs_sample = e(sample)
	capture reghdfe Dl_vloans_b Linter_bra  LDl_hpi  $D_control_hp [aw=w1] if fs_sample == 1, absorb(yryear_1994-yryear_2005 county_1-county_1048) stage(first)
 	global N = e(N)
	global dof = (e(N)-1)/e(df_r)  
	
	qui sureg (fs_mean: Dl_vloans_b_p  Linter_bra_p LDl_hpi_p , nocons) ///
		(rf_mean:  Dl_hpi_p Linter_bra_p LDl_hpi_p  , nocons ) [aw=w1] if fs_sample  ==1  
	mat suestb = e(b)
	mat suestV = e(V)*$dof
 	
	global specid = 109
	dis $specid
	global exexog1 "Linter_bra_p"
	global exexogk "Linter_bra_p"
	qui output_tables $exexog1  $exexogk $specid
	
	** Table 5 (3)
	xtivreg2 Dl_hpi (Dl_lir_b  = Linter_bra) LDl_hpi  $D_control_hp yr* [aw=w1], fe  partial(yr*)  first
		drop fs_sample
	gen fs_sample = e(sample)
	capture reghdfe Dl_lir_b Linter_bra  LDl_hpi  $D_control_hp [aw=w1] if fs_sample == 1, absorb(yryear_1994-yryear_2005 county_1-county_1048) stage(first)
 	global N = e(N)
	global dof = (e(N)-1)/e(df_r)  
	
	qui sureg (fs_mean: Dl_lir_b_p  Linter_bra_p LDl_hpi_p , nocons) ///
		(rf_mean:  Dl_hpi_p Linter_bra_p LDl_hpi_p  , nocons ) [aw=w1] if fs_sample  ==1  
	mat suestb = e(b)
	mat suestV = e(V)*$dof
 	
	global specid = 110
	dis $specid
	global exexog1 "Linter_bra_p"
	global exexogk "Linter_bra_p"
	qui output_tables $exexog1  $exexogk $specid
