drop _all
clear mata
set memory 300000
set matsize 2000
use USKLEMS, clear
sort Year
merge Year using Instruments
tab _m
drop if _m == 2
drop _m
drop if YYDif == .
save aa, replace


**
capture program drop output_tables
program output_tables
	args  exexog1 exexogk specid 
{
	
	global exexog1 "`exexog1'" // first excluded exogenous variable
	global exexogk "`exexogk'" // last excluded exogenous variable
	 
	local b_fs_start = colnumb(suestb,"fs_mean:$exexog1")
	local b_fs_end = colnumb(suestb,"fs_mean:$exexogk")
	local b_rf_start = colnumb(suestb,"rf_mean:$exexog1")
	local b_rf_end = colnumb(suestb,"rf_mean:$exexogk")

	local vcov_fs_start = colnumb(suestV,"fs_mean:$exexog1")
	local vcov_fs_end = colnumb(suestV,"fs_mean:$exexogk")
	local vcov_rf_start = colnumb(suestV,"rf_mean:$exexog1")
	local vcov_rf_end = colnumb(suestV,"rf_mean:$exexogk")

	mat b_fs = suestb[1,`b_fs_start'..`b_fs_end']
	mat vcov_fs = suestV[`vcov_fs_start'..`vcov_fs_end',`vcov_fs_start'..`vcov_fs_end']
	mat b_rf = suestb[1,`b_rf_start'..`b_rf_end']
	mat vcov_rf = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_rf_start'..`vcov_rf_end']
	mat vcov_rf_fs = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_fs_start'..`vcov_fs_end']
 
	mat b = b_fs, b_rf
	mat list b // these would match the equation-by-equation regression results.
	mat2txt, matrix(b) saving(b_`specid') replace  // export with specification id

	mat vcov = vcov_fs, vcov_rf_fs' \ vcov_rf_fs , vcov_rf
	mat list vcov // these would match the equation-by-equation regression results.
	mat2txt, matrix(vcov) saving(vcov_`specid')  replace
	
	count if ivsample == 1
	global N = r(N)
	mat accum ZZ = $exexog1 - $exexogk if ivsample, nocons
	mat ZZ = ZZ/$N
	mat2txt, matrix(ZZ) saving(ZZ_`specid')  replace
 
}
end

*Baseline IV Table 2 Panel A 
local counter = 0
foreach m in lnMExpDif lnMetalsPriceDif SW1 SW7 {
 
		local i = `i' + 1
		use aa, clear
		quietly drop if `m' == .
		quietly tab Industry, gen(I)
		global k = r(r)
		foreach j in lnURateDif `m' {
			forvalues k = 1/$k {
				quietly generate `j'I`k' = `j'*I`k'
				}
			}
		quietly tab Year, gen(Y)
		global kk = r(r)
		quietly regress XXDif I2-I$k Y2-Y$kk lnURateDifI2-lnURateDifI$k `m'I2-`m'I$k
 		global N = e(N)
		global K = e(N)- e(df_r)
		global dof = (e(N))/(e(df_r)-1) // (N)/(N-K)
		
		quietly ivregress 2sls YYDif I2-I$k Y2-Y$kk lnURateDifI2-lnURateDifI$k (XXDif = `m'I2-`m'I$k)
		

		gen ivsample = e(sample)
		global exexog1 "`m'I2"
		global exexogk "`m'I$k"
		foreach vv of varlist $exexog1 - $exexogk YYDif XXDif{
			qui reg `vv' I2-I$k Y2-Y$kk lnURateDifI2-lnURateDifI$k if ivsample
			predict `vv'_adj, residual
		}
		global exexog1_adj "`m'I2_adj"
		global exexogk_adj "`m'I${k}_adj"


		global  spec  = "(fs_mean: XXDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		global  spec = "$spec (rf_mean: YYDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		sureg $spec if ivsample 
				
		mat suestb = e(b)
		mat suestV = e(V)*$dof

		global specid = 187+`counter'
		dis $specid
		qui output_tables $exexog1_adj $exexogk_adj $specid
		local ++counter

	}


*No URate controls Table 2 Panel B 
local counter = 0
local i = 0
foreach m in lnMExpDif lnMetalsPriceDif SW1 SW7 {
		local i = `i' + 1
		use aa, clear
		quietly drop if `m' == .
		quietly tab Industry, gen(I)
		global k = r(r)
		foreach j in `m' {
			forvalues k = 1/$k {
				quietly generate `j'I`k' = `j'*I`k'
				}
			}
		quietly tab Year, gen(Y)
		global kk = r(r)
		
		regress  XXDif `m'I2-`m'I$k I2-I$k Y2-Y$kk  
		global dof = (e(N))/(e(df_r)-1) // (N)/(N-K)
		
		quietly ivregress 2sls YYDif I2-I$k Y2-Y$kk (XXDif = `m'I2-`m'I$k)

		gen ivsample = e(sample)
		global exexog1 "`m'I2"
		global exexogk "`m'I$k"
		foreach vv of varlist $exexog1 - $exexogk YYDif XXDif{
			qui reg `vv' I2-I$k Y2-Y$kk  if ivsample
			predict `vv'_adj, residual
		}
		global exexog1_adj "`m'I2_adj"
		global exexogk_adj "`m'I${k}_adj"

		
		global  spec  = "(fs_mean: XXDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		global  spec = "$spec (rf_mean: YYDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		sureg $spec if ivsample 
				
		mat suestb = e(b)
		mat suestV = e(V)*$dof

		global specid = 191+`counter'
		dis $specid
		qui output_tables $exexog1_adj $exexogk_adj $specid
		local ++counter
	}
 


*Substitute Fed Cap Utilization Table 2 Panel C
local counter = 0
local i = 0
foreach m in lnMExpDif lnMetalsPriceDif SW1 SW7 {
		local i = `i' + 1
		use aa, clear
		quietly drop if `m' == .
		quietly tab Industry, gen(I)
		global k = r(r)
		foreach j in lnCapUDif `m' {
			forvalues k = 1/$k {
				quietly generate `j'I`k' = `j'*I`k'
				}
			}
		quietly tab Year, gen(Y)
		global kk = r(r)
 
 		regress  XXDif `m'I2-`m'I$k I2-I$k Y2-Y$kk  lnCapUDifI2-lnCapUDifI$k
		global dof = (e(N))/(e(df_r)-1) // (N)/(N-K)
		quietly ivregress 2sls YYDif I2-I$k Y2-Y$kk lnCapUDifI2-lnCapUDifI$k (XXDif = `m'I2-`m'I$k)
		
		gen ivsample = e(sample)
		global exexog1 "`m'I2"
		global exexogk "`m'I$k"
		foreach vv of varlist $exexog1 - $exexogk YYDif XXDif{
			qui reg `vv' I2-I$k Y2-Y$kk lnCapUDifI2-lnCapUDifI$k  if ivsample
			predict `vv'_adj, residual
		}
		global exexog1_adj "`m'I2_adj"
		global exexogk_adj "`m'I${k}_adj"

		
		global  spec  = "(fs_mean: XXDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		global  spec = "$spec (rf_mean: YYDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		sureg $spec if ivsample 
				
		mat suestb = e(b)
		mat suestV = e(V)*$dof 

		global specid = 195+`counter'
		dis $specid
		qui output_tables $exexog1_adj $exexogk_adj $specid
		local ++counter
	}
 
 *Add Fed Cap Utilization Table 2 Panel D
local counter = 0
local i = 0
foreach m in lnMExpDif lnMetalsPriceDif SW1 SW7 {
		local i = `i' + 1
		use aa, clear
		quietly drop if `m' == .
		quietly tab Industry, gen(I)
		global k = r(r)
		foreach j in lnCapUDif lnURateDif `m' {
			forvalues k = 1/$k {
				quietly generate `j'I`k' = `j'*I`k'
				}
			}
		quietly tab Year, gen(Y)
		global kk = r(r)
	 
	  	regress  XXDif `m'I2-`m'I$k I2-I$k Y2-Y$kk  lnCapUDifI2-lnCapUDifI$k lnURateDifI2-lnURateDifI$k 
		global dof = (e(N))/(e(df_r)-1) // (N)/(N-K)
		
		quietly ivregress 2sls YYDif I2-I$k Y2-Y$kk lnCapUDifI2-lnCapUDifI$k lnURateDifI2-lnURateDifI$k (XXDif = `m'I2-`m'I$k)
	
		gen ivsample = e(sample)
		global exexog1 "`m'I2"
		global exexogk "`m'I$k"
		foreach vv of varlist $exexog1 - $exexogk YYDif XXDif{
			qui reg `vv' I2-I$k Y2-Y$kk lnCapUDifI2-lnCapUDifI$k lnURateDifI2-lnURateDifI$k if ivsample
			predict `vv'_adj, residual
		}
		global exexog1_adj "`m'I2_adj"
		global exexogk_adj "`m'I${k}_adj"

		
		global  spec  = "(fs_mean: XXDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		global  spec = "$spec (rf_mean: YYDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		sureg $spec if ivsample 
				
		mat suestb = e(b)
		mat suestV = e(V)*$dof

		global specid = 199+`counter'
		dis $specid
		qui output_tables $exexog1_adj $exexogk_adj $specid
		local ++counter
}

*No Year Dummies Table 2 Panel E
local counter = 0
local i = 0
foreach m in lnMExpDif lnMetalsPriceDif SW1 SW7 {
		local i = `i' + 1
		use aa, clear
		quietly drop if `m' == .
		quietly tab Industry, gen(I)
		global k = r(r)
		foreach j in lnURateDif `m' {
			forvalues k = 1/$k {
				quietly generate `j'I`k' = `j'*I`k'
				}
			}
		quietly tab Year, gen(Y)
		global kk = r(r)
		
		regress  XXDif `m'I2-`m'I$k I2-I$k  lnURateDifI2-lnURateDifI$k 
		global dof = (e(N))/(e(df_r)-1) // (N)/(N-K)
		
		ivregress 2sls YYDif I2-I$k lnURateDifI1-lnURateDifI$k (XXDif = `m'I1-`m'I$k)
		
		gen ivsample = e(sample)
		global exexog1 "`m'I2"
		global exexogk "`m'I$k"
		foreach vv of varlist $exexog1 - $exexogk YYDif XXDif{
			qui reg `vv' I2-I$k lnURateDifI1-lnURateDifI$k if ivsample
			predict `vv'_adj, residual
		}
		global exexog1_adj "`m'I2_adj"
		global exexogk_adj "`m'I${k}_adj"

		
		global  spec  = "(fs_mean: XXDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		global  spec = "$spec (rf_mean: YYDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		sureg $spec if ivsample 
				
		mat suestb = e(b)
		mat suestV = e(V)*$dof 

		global specid = 203+`counter'
		dis $specid
		qui output_tables $exexog1_adj $exexogk_adj $specid
		local ++counter
	}

*******************************************************************

*Table III

drop _all
clear mata
set memory 300000
set matsize 2000
use USKLEMS, clear
sort Year
merge Year using Instruments
tab _m
drop if _m == 2
drop _m
sort Industry Year
merge Industry Year using CapUtilization
tab _m
keep if _m == 3
sort Industry Year
drop if YYDif == .

quietly tab Industry, gen(I)
global k = r(r)
foreach m in lnURateDif lnMExpDif SW13 {
	forvalues k = 1/$k {
		quietly generate `m'I`k' = `m'*I`k'
		}
	}
quietly tab Year, gen(Y)
global kk = r(r)
quietly sort Industry Year
foreach m in XXDif QDif {
	forvalues k = 1/4 {
		generate L`k'`m' = `m'[_n-`k'] if Industry == Industry[_n-`k'] & Year == Year[_n-`k'] + `k'
		}
	}
 
local specid_counter = 211
foreach m in QDif XXDif {
 		regress  `m'  lnMExpDifI* I2-I$k Y2-Y$kk lnURateDifI*
		global dof = (e(N))/(e(df_r)-1) // (N)/(N-K)
		
	quietly ivregress 2sls lnCapUIDif I2-I$k Y2-Y$kk lnURateDifI* (`m' = lnMExpDifI*)
	capture drop ivsample
			gen ivsample = e(sample)
		global exexog1 "lnMExpDifI1"
		global exexogk "lnMExpDifI21"
		foreach vv of varlist $exexog1 - $exexogk lnCapUIDif `m' {
			capture drop `vv'_adj
			qui reg `vv' I2-I$k Y2-Y$kk lnURateDifI* if ivsample ==1
			predict `vv'_adj, residual
		}
		global exexog1_adj "lnMExpDifI1_adj"
		global exexogk_adj "lnMExpDifI21_adj"

		
		global  spec  = "(fs_mean: `m'_adj $exexog1_adj - $exexogk_adj, nocons) "
		global  spec = "$spec (rf_mean: lnCapUIDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		sureg $spec if ivsample 
				
		mat suestb = e(b)
		mat suestV = e(V)*$dof

		global specid = `specid_counter'
		dis $specid
		qui output_tables $exexog1_adj $exexogk_adj $specid
		local ++specid_counter
 
  
		
		quietly ivregress 2sls YYDif I2-I$k Y2-Y$kk lnURateDifI* (`m' = lnMExpDifI*)
		capture drop ivsample
	 		gen ivsample = e(sample)
		global exexog1 "lnMExpDifI1"
		global exexogk "lnMExpDifI21"
		foreach vv of varlist $exexog1 - $exexogk YYDif `m' {
			capture drop `vv'_adj
			qui reg `vv' I2-I$k Y2-Y$kk lnURateDifI* if ivsample==1
			predict `vv'_adj, residual
		}
		global exexog1_adj "lnMExpDifI1_adj"
		global exexogk_adj "lnMExpDifI21_adj"

		
		global  spec  = "(fs_mean: `m'_adj $exexog1_adj - $exexogk_adj, nocons) "
		global  spec = "$spec (rf_mean: YYDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		sureg $spec if ivsample 
				
		mat suestb = e(b)
		mat suestV = e(V)*$dof 

		global specid = `specid_counter'
		dis $specid
		qui output_tables $exexog1_adj $exexogk_adj $specid
		local ++specid_counter
	 
 
}
 
 **************************************************************************

*Table IV:  Defense expenditures by country
 drop _all
set memory 600000
set matsize 4000
set maxvar 20000
use EUKLEMS, clear
keep country code desc Year Goods YYDif XXDif QDif
sort country Year
merge country Year using EUInstruments
tab _m
drop if _m == 2
drop _m
save aa, replace



*1st stage regressions

use aa, clear
quietly drop if lnMExpDifSIPRI == .
quietly drop if lnURateDifFRED == .
quietly drop if YYDif == .
quietly drop if XXDif == .
sort country code Year
forvalues i = 1/4 {
	quietly generate double L`i'XXDif = XXDif[_n-`i'] if country == country[_n-`i'] & code == code[_n-`i'] & Year == Year[_n-`i'] + `i'
	}
egen Industry = group(code)
tab country, gen(C)
save aaa, replace

local specid_counter = 221
foreach c in 1 7 14 17 {

	use aaa, clear
	quietly keep if C`c' == 1
	egen m = group(code country)
	quietly tab m, gen(I)
	global k = r(r)
	egen mm = group(country Year)
	quietly tab mm, gen(Y)
	global kk = r(r) 
	foreach j in lnMExpDifSIPRI lnURateDifFRED {
		forvalues i = 1/$k {
			quietly generate `j'I`i' = I`i'*`j'
			}
		}
		
  	regress  XXDif  lnMExpDifSIPRII2-lnMExpDifSIPRII$k  I1-I$k Y2-Y$kk lnURateDifFREDI2-lnURateDifFREDI$k
	global dof = (e(N))/(e(df_r)-1) // (N)/(N-K)
		
	quietly ivregress 2sls YYDif I1-I$k Y2-Y$kk lnURateDifFREDI2-lnURateDifFREDI$k (XXDif = lnMExpDifSIPRII2-lnMExpDifSIPRII$k)
	
 	capture drop ivsample
	 		gen ivsample = e(sample)
		global exexog1 "lnMExpDifSIPRII2"
		global exexogk "lnMExpDifSIPRII$k"
		foreach vv of varlist $exexog1 - $exexogk YYDif XXDif {
			capture drop `vv'_adj
			qui reg `vv' I2-I$k Y2-Y$kk lnURateDifFREDI2-lnURateDifFREDI$k if ivsample==1
			predict `vv'_adj, residual
		}
		global exexog1_adj "${exexog1}_adj"
		global exexogk_adj "${exexogk}_adj"

		
		global  spec  = "(fs_mean: XXDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		global  spec = "$spec (rf_mean: YYDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		sureg $spec if ivsample 
				
		mat suestb = e(b)
		mat suestV = e(V)*$dof 

		global specid = `specid_counter'
		dis $specid
		qui output_tables $exexog1_adj $exexogk_adj $specid
		local ++specid_counter
	}
 
 ***********Table V

*Prepare data

drop _all
clear mata
set memory 300000

use USNAICSEUKLEMS, clear
sort Year
merge Year using Instruments
tab _m
drop if _m == 2
drop _m
drop if YYDif == .
drop if XXDif == .
egen Industry = group(code)
save aa, replace

*Panel A: Baseline

local counter = 0
foreach m in lnMExpDif lnOilPriceDif SW1 SW5 SW6 SW10 {
		local i = `i' + 1
		use aa, clear
		quietly drop if `m' == .
		quietly tab Industry, gen(I)
		global k = r(r)
		foreach j in lnURateDif `m' {
			forvalues k = 1/$k {
				quietly generate `j'I`k' = `j'*I`k'
				}
			}
		quietly tab Year, gen(Y)
		global kk = r(r)
		
		regress  XXDif `m'I2-`m'I$k I2-I$k Y2-Y$kk lnURateDifI2-lnURateDifI$k
		global dof = (e(N))/(e(df_r)-1) // (N)/(N-K)
	
		quietly ivregress 2sls YYDif I2-I$k Y2-Y$kk lnURateDifI2-lnURateDifI$k (XXDif = `m'I2-`m'I$k)
		gen ivsample = e(sample)
		global exexog1 "`m'I2"
		global exexogk "`m'I$k"
		foreach vv of varlist $exexog1 - $exexogk YYDif XXDif{
			qui reg `vv' I2-I$k Y2-Y$kk lnURateDifI1-lnURateDifI$k if ivsample
			predict `vv'_adj, residual
		}
		global exexog1_adj "`m'I2_adj"
		global exexogk_adj "`m'I${k}_adj"

		
		global  spec  = "(fs_mean: XXDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		global  spec = "$spec (rf_mean: YYDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		sureg $spec if ivsample 
				
		mat suestb = e(b)
		mat suestV = e(V)*$dof 

		global specid = 215+`counter'
		dis $specid
		qui output_tables $exexog1_adj $exexogk_adj $specid
		local ++counter
 
	}

****************Table VI

*Prepare data

drop _all
clear mata
set memory 300000
 
use USSICEUKLEMS, clear
sort Year
merge Year using Instruments
tab _m
drop if _m == 2
drop _m
drop if YYDif == .
drop if XXDif == .
egen Industry = group(code)
save aa, replace
 

*Panel A: Baseline

local counter = 0
foreach m in lnMExpDif SW1 SW3 SW4 SW7 SW10 {
		local i = `i' + 1
		use aa, clear
		quietly drop if `m' == .
		quietly tab Industry, gen(I)
		global k = r(r)
		foreach j in lnURateDif `m' {
			forvalues k = 1/$k {
				quietly generate `j'I`k' = `j'*I`k'
				}
			}
		quietly tab Year, gen(Y)
		global kk = r(r)
		
		regress  XXDif `m'I2-`m'I$k I2-I$k Y2-Y$kk lnURateDifI2-lnURateDifI$k
		global dof = (e(N))/(e(df_r)-1) // (N)/(N-K) 
		
		quietly ivregress 2sls YYDif I2-I$k Y2-Y$kk lnURateDifI2-lnURateDifI$k (XXDif = `m'I2-`m'I$k)
		gen ivsample = e(sample)
		global exexog1 "`m'I2"
		global exexogk "`m'I$k"
		foreach vv of varlist $exexog1 - $exexogk YYDif XXDif{
			qui reg `vv' I2-I$k Y2-Y$kk lnURateDifI1-lnURateDifI$k if ivsample
			predict `vv'_adj, residual
		}
		global exexog1_adj "`m'I2_adj"
		global exexogk_adj "`m'I${k}_adj"

		
		global  spec  = "(fs_mean: XXDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		global  spec = "$spec (rf_mean: YYDif_adj $exexog1_adj - $exexogk_adj, nocons) "
		sureg $spec if ivsample 
				
		mat suestb = e(b)
		mat suestV = e(V)*$dof 

		global specid = 225+`counter'
		dis $specid
		qui output_tables $exexog1_adj $exexogk_adj $specid
		local ++counter
 
	}
