clear 
clear matrix
set memory 800m 
set more off
 

use "master_data_file.dta"


*********************************
* Preliminary: prepare data for analysis
*********************************
run "./Do_Files/supportfile.do"

***********************************************************************************
* Section I: create dataset: dependent variables and regressors 
***********************************************************************************
set more off

***********************************************************************************
*Part I: Main Regressor
***********************************************************************************

**Generate market shares and C4 for LIS Weights for BASIC PDP:
gen true_weight_check_cw2=true_weight_check_cw if pdp==1 & basic==1
sort true_weight_check_cw2
gen idd=_n
bysort   new_id1: egen C1_weight2=max(true_weight_check_cw2) 
gen temp= C1_weight2-true_weight_check_cw2
gen C1_plan_weight2=1 if temp==0
replace C1_plan_weight2=C1_plan_weight2*idd
bysort   new_id1: egen maxidd=max(C1_plan_weight2)
replace C1_plan_weight2=0 if maxidd!=idd | C1_plan_weight2==.
replace C1_plan_weight2=1 if C1_plan_weight2!=0
bysort  new_id1 (idd): gen C2_plan_weight2=1 if  C1_plan_weight2[_n+1]==1
replace C2_plan_weight2=0 if C2_plan_weight2!=1
bysort   new_id1: egen C2_weight2=max(true_weight_check_cw2*C2_plan_weight2)
bysort  new_id1 (idd): gen C3_plan_weight2=1 if  C1_plan_weight2[_n+2]==1
replace C3_plan_weight2=0 if C3_plan_weight2!=1
bysort   new_id1: egen C3_weight2=max(true_weight_check_cw2*C3_plan_weight2)
bysort  new_id1 (idd): gen C4_plan_weight2=1 if  C1_plan_weight2[_n+3]==1
replace C4_plan_weight2=0 if C4_plan_weight2!=1
bysort   new_id1: egen C4_weight2=max(true_weight_check_cw2*C4_plan_weight2)
gen conc_weig_basicpdpd_c4=C1_weight2+C2_weight2+C3_weight2+C4_weight2
drop temp maxidd idd C1_weight2 C2_weight2 C3_weight2 C4_weight2 C4_plan_weight2 C3_plan_weight2 C2_plan_weight2 C1_plan_weight2 


***********************************************************************************
*Part II: Controls
***********************************************************************************

* Generate Hershfindal by firm
gen enrol_tot_share=0
replace enrol_tot_share=enrol_tot_num/enrol_tot_denominator if enrol_tot_num!=0 & enrol_tot_num!=. & enrol_tot_denominator!=0 & enrol_tot_denominator!=.
bys new_id1 Parent_Organization: egen firm_tot_share=sum(enrol_tot_share)

sort new_id1 Parent_Organization
gen iddd=_n
bys new_id1 Parent_Organization: egen temp=min(iddd)
gen temp2=1 if iddd==temp
bysort  new_id1: egen num_firms=total(temp2)
gen firm_tot_share2=firm_tot_share if temp2==1
bysort  new_id1: egen hershf_firm_tot=sum(firm_tot_share2^2)
replace hershf_firm_tot=(hershf_firm_tot-(1/num_firms))/(1-(1/num_firms))
drop iddd temp temp2

***********************************************************************************************************
** Get the sample right before proceeding: 1 observation per year/region
***********************************************************************************************************
duplicates drop regionid year, force
drop if regionid==. | year==.


***********************************************************************************************************
*Part III: Dependent variable
********************************
gen logmean_w_reg_bpr=log(mean_w_reg_basprem)
bysort regionid (year): gen logmean_w_reg_bpr_ch=logmean_w_reg_bpr[_n]-logmean_w_reg_bpr[_n-1]  if year>2006

***********************************************************************************************************
* Other exogenous covariates
gen change=year>2008
* Lagged variables
bysort regionid (year): gen laghershf_firm_tot = hershf_firm_tot[_n-1] if year>2006
bysort regionid (year): gen lagunemploymentrate = unemploymentrate[_n-1] if year>2006

***********************************************************************************************************
* Regression analysis:
***********************************************************************************************************

drop if year==2006








***********************************************************************************
* Section II: analysis
***********************************************************************************

***********************************************************************************************************
* Summary Statistics by Market, 2007-2011, Mareket Level data
***********************************************************************************************************

sum mean_w_reg_basprem   ///
	logmean_w_reg_bpr_ch conc_weig_basicpdpd_c4  ///
	mapd_regio_2006share MA_2005_penetration MA_2004_penetration MA_2003_penetration


*****************************************
gen year2009=0
replace year2009=1 if year>2008
gen regio_2006share2= mapd_regio_2006share* year2009


***********************************************************************************************************
* Regression analysis
***********************************************************************************************************




 /* 
local ctrl1 ""
local ctrl2 "ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local ctrl3 "laghershf_firm_tot  lagunemploymentrate"
local ctrl4 "laghershf_firm_tot  lagunemploymentrate ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local ctrl5 "laghershf_firm_tot  lagunemploymentrate mean_weig_reg_vintage mean_weig_reg_pharmacies mean_weig_reg_drugs"
local ctrl6 "laghershf_firm_tot  lagunemploymentrate mean_weig_reg_vintage mean_weig_reg_pharmacies mean_weig_reg_drugs ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local outcomes "logmean_w_reg_bpr_ch"
local instruments "regio_2006share2"
foreach o in `outcomes' {
forvalues i=1(1)1{
*xi: ivregress 2sls `o' `ctrl`i'' i.year i.regionid (conc_weig_basicpdpd_c4 = `instruments'), cluster(regionid) small first
*estat firststage
 xi: ivreg2 `o' `ctrl`i'' i.year i.regionid (conc_weig_basicpdpd_c4 = `instruments'), cluster(regionid) small first
dis e(cdf) // actually uses CD first-stage F
  }
}

*/

**
capture program drop output_tables
program output_tables
	args  exexog1 exexogk specid 
{
	
	global exexog1 "`exexog1'" // first excluded exogenous variable
	global exexogk "`exexogk'" // last excluded exogenous variable
	 
	local b_fs_start = colnumb(suestb,"fs_mean:$exexog1")
	local b_fs_end = colnumb(suestb,"fs_mean:$exexogk")
	local b_rf_start = colnumb(suestb,"rf_mean:$exexog1")
	local b_rf_end = colnumb(suestb,"rf_mean:$exexogk")

	local vcov_fs_start = colnumb(suestV,"fs_mean:$exexog1")
	local vcov_fs_end = colnumb(suestV,"fs_mean:$exexogk")
	local vcov_rf_start = colnumb(suestV,"rf_mean:$exexog1")
	local vcov_rf_end = colnumb(suestV,"rf_mean:$exexogk")

	mat b_fs = suestb[1,`b_fs_start'..`b_fs_end']
	mat vcov_fs = suestV[`vcov_fs_start'..`vcov_fs_end',`vcov_fs_start'..`vcov_fs_end']
	mat b_rf = suestb[1,`b_rf_start'..`b_rf_end']
	mat vcov_rf = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_rf_start'..`vcov_rf_end']
	mat vcov_rf_fs = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_fs_start'..`vcov_fs_end']
 
	mat b = b_fs, b_rf
	mat list b // these would match the equation-by-equation regression results.
	mat2txt, matrix(b) saving(b_`specid') replace  // export with specification id

	mat vcov = vcov_fs, vcov_rf_fs' \ vcov_rf_fs , vcov_rf
	mat list vcov // these would match the equation-by-equation regression results.
	mat2txt, matrix(vcov) saving(vcov_`specid')  replace
 
}
end


local counter = 0
  local ctrl1 ""
local ctrl2 " ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local ctrl3 " laghershf_firm_tot  lagunemploymentrate"
local ctrl4 " laghershf_firm_tot  lagunemploymentrate ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local ctrl5 " laghershf_firm_tot  lagunemploymentrate mean_weig_reg_vintage mean_weig_reg_pharmacies mean_weig_reg_drugs"
local ctrl6 " laghershf_firm_tot  lagunemploymentrate mean_weig_reg_vintage mean_weig_reg_pharmacies mean_weig_reg_drugs ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local outcomes "logmean_w_reg_bpr_ch"
local endo "conc_weig_basicpdpd_c4"
local instruments "regio_2006share2"
global exexog1 "`instruments'"
global exexogk "`instruments'"
foreach o in `outcomes' {
forvalues i=1(1)6{

	capture estimates store drop
	xi: regress `endo' `instruments' `ctrl`i'' i.year i.regionid ,  
	global N = e(N)
	global K = e(N)- e(df_r)
	global dof = (e(N)-1)/(e(df_r)-1) // (N-1)/(N-K-1) 1 for the constant term
 
 
 
	sureg (fs_mean:   `endo' `instruments' `ctrl`i'' i.year i.regionid) (rf_mean:   `o' `instruments' `ctrl`i'' i.year i.regionid )
	mat suestb = e(b)
	mat suestV = e(V) * $dof
	
	global specid = 102+`counter'
	dis $specid
	qui output_tables $exexog1  $exexogk $specid
	local ++counter 
}
}


/*
// original code
estimates store drop
  local ctrl1 ""
local ctrl2 " ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local ctrl3 " laghershf_firm_tot  lagunemploymentrate"
local ctrl4 " laghershf_firm_tot  lagunemploymentrate ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local ctrl5 " laghershf_firm_tot  lagunemploymentrate mean_weig_reg_vintage mean_weig_reg_pharmacies mean_weig_reg_drugs"
local ctrl6 " laghershf_firm_tot  lagunemploymentrate mean_weig_reg_vintage mean_weig_reg_pharmacies mean_weig_reg_drugs ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local endo "conc_weig_basicpdpd_c4"
local outcomes "logmean_w_reg_bpr_ch"
local instruments "regio_2006share2"
global exog1 "`instruments'"
global exogp "`instruments'"
foreach o in `outcomes' {
forvalues i=6(1)6{
xi: regress `endo' `instruments' `ctrl`i'' i.year i.regionid ,  
global N = e(N)
global K = e(N)- e(df_r)
global dof = (e(N)-1)/(e(df_r)-1) // (N-1)/(N-K)
 
estimates store fs

}
}




  local ctrl1 ""
local ctrl2 "ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local ctrl3 "laghershf_firm_tot  lagunemploymentrate"
local ctrl4 "laghershf_firm_tot  lagunemploymentrate ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local ctrl5 "laghershf_firm_tot  lagunemploymentrate mean_weig_reg_vintage mean_weig_reg_pharmacies mean_weig_reg_drugs"
local ctrl6 "laghershf_firm_tot  lagunemploymentrate mean_weig_reg_vintage mean_weig_reg_pharmacies mean_weig_reg_drugs ttrend1 ttrend2 ttrend3 ttrend4 ttrend5 ttrend6 ttrend7 ttrend8 ttrend9 ttrend10 ttrend11 ttrend12 ttrend13 ttrend14 ttrend15 ttrend16 ttrend17 ttrend18 ttrend19 ttrend20 ttrend21 ttrend22 ttrend23 ttrend24 ttrend25 ttrend26 ttrend27 ttrend28 ttrend29 ttrend30 ttrend31 ttrend32 ttrend33 ttrend34"
local outcomes "logmean_w_reg_bpr_ch"
local instruments "regio_2006share2"
foreach o in `outcomes' {
forvalues i=1(1)6{
xi: regress `o' `instruments' `ctrl`i'' i.year i.regionid  
estimates store rf


 }
 
 

}


 
qui suest fs rf, vce(cluster regionid)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof


local b_fs_start = colnumb(suestb,"fs_mean:$exog1")
local b_fs_end = colnumb(suestb,"fs_mean:$exogp")
local b_rf_start = colnumb(suestb,"rf_mean:$exog1")
local b_rf_end = colnumb(suestb,"rf_mean:$exogp")

local vcov_fs_start = colnumb(suestV,"fs_mean:$exog1")
local vcov_fs_end = colnumb(suestV,"fs_mean:$exogp")
local vcov_rf_start = colnumb(suestV,"rf_mean:$exog1")
local vcov_rf_end = colnumb(suestV,"rf_mean:$exogp")

mat b_fs = suestb[1,`b_fs_start'..`b_fs_end']
mat vcov_fs = suestV[`vcov_fs_start'..`vcov_fs_end',`vcov_fs_start'..`vcov_fs_end']
mat b_rf = suestb[1,`b_rf_start'..`b_rf_end']
mat vcov_rf = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_rf_start'..`vcov_rf_end']
mat vcov_rf_fs = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_fs_start'..`vcov_fs_end']

mat b = b_fs, b_rf
mat list b // these would match the equation-by-equation regression results.
mat2txt, matrix(b) saving(b_107)  // export with specification id

mat vcov = vcov_fs, vcov_rf_fs' \ vcov_rf_fs , vcov_rf
mat list vcov // these would match the equation-by-equation regression results.
mat2txt, matrix(vcov) saving(vcov_107)  

mat result = b_fs,vcov_fs, b_rf, vcov_rf, vcov_rf_fs
mat list result
*/
