 
clear all
set more off  
set matsize 8000

/******************************************************************************/
/***************    German scietists patents         **************************/
/******************************************************************************/

*** Figure 1
use patenting_years_german_chemists.dta, clear
browse

/******************************************************************************/
/***************    Patent count data                **************************/
/******************************************************************************/


use patent_classes.dta, clear

tab main, gen (maind)
egen main_nr=group(main)
tab gyear, gen(td_)
 
***
capture program drop output_tables
program output_tables
	args  exog1 exogp specid 
{
	
	global exog1 "`exog1'"
	global exogp "`exogp'"
	local b_fs_start = colnumb(suestb,"fs_mean:$exog1")
	local b_fs_end = colnumb(suestb,"fs_mean:$exogp")
	local b_rf_start = colnumb(suestb,"rf_mean:$exog1")
	local b_rf_end = colnumb(suestb,"rf_mean:$exogp")

	local vcov_fs_start = colnumb(suestV,"fs_mean:$exog1")
	local vcov_fs_end = colnumb(suestV,"fs_mean:$exogp")
	local vcov_rf_start = colnumb(suestV,"rf_mean:$exog1")
	local vcov_rf_end = colnumb(suestV,"rf_mean:$exogp")

	mat b_fs = suestb[1,`b_fs_start'..`b_fs_end']
	mat vcov_fs = suestV[`vcov_fs_start'..`vcov_fs_end',`vcov_fs_start'..`vcov_fs_end']
	mat b_rf = suestb[1,`b_rf_start'..`b_rf_end']
	mat vcov_rf = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_rf_start'..`vcov_rf_end']
	mat vcov_rf_fs = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_fs_start'..`vcov_fs_end']

	mat b = b_fs, b_rf
	mat list b // these would match the equation-by-equation regression results.
	mat2txt, matrix(b) saving(b_`specid') replace  // export with specification id

	mat vcov = vcov_fs, vcov_rf_fs' \ vcov_rf_fs , vcov_rf
	mat list vcov // these would match the equation-by-equation regression results.
	mat2txt, matrix(vcov) saving(vcov_`specid')  replace
 
}
end
***** Table 4 (1) spe id 231
*1
ivreg count_us (treat_us = treat_dis_pre33) td_* maind*  , cluster(main_nr)
qui reg   treat_us  treat_dis_pre33  td_* maind* 
global dof = (e(N)-1)/(e(df_r)-1) // (N-1)/(N-K)
sureg  (fs_mean: treat_us  treat_dis_pre33  td_* maind* ) (rf_mean: count_us  treat_dis_pre33  td_* maind* )
 
mat suestb = e(b)
mat suestV = e(V) * $dof // highly non-singular so use delta method
output_tables "treat_dis_pre33" "treat_dis_pre33" 231
mat result = b_fs, vcov_fs,b_rf,vcov_rf,vcov_rf_fs
mat list result
dis "divide by " $N-1 "/" $N-$K "*" $m "/" $m-1 
 

*2 Table 4 (2) spe id 236
ivreg count_us (treat_us = treat_dis_pre33) count_for td_* maind* class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p, cluster(main_nr)

qui reg   treat_us  treat_dis_pre33 count_for td_* maind* class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p  
 
global dof = (e(N)-1)/(e(df_r)-1_ // (N-1)/(N-K)
sureg (fs_mean:  treat_us  treat_dis_pre33 count_for td_* maind* class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p ) ///
		(rf_mean: count_us  treat_dis_pre33  count_for td_* maind* class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p )
 
mat suestb = e(b)
mat suestV = e(V) * $dof

output_tables "treat_dis_pre33" "treat_dis_pre33" 236
mat result = b_fs, vcov_fs,b_rf,vcov_rf,vcov_rf_fs
mat list result // these would match the equation-by-equation regression or ivreg results.



*3
ivreg count_us (treat_int_us = treat_int_dis_pre33 ) td_* maind*  , cluster(main_nr)
qui reg   treat_us  treat_int_dis_pre33  td_* maind*
global dof = (e(N)-1)/(e(df_r)-1) // (N-1)/(N-K)
sureg (fs_mean: treat_us  treat_int_dis_pre33   td_* maind* ) (rf_mean:  count_us  treat_int_dis_pre33   td_* maind* )
 
mat suestb = e(b)
mat suestV = e(V) * $dof
output_tables "treat_int_dis_pre33" "treat_int_dis_pre33" 237
mat result = b_fs, vcov_fs,b_rf,vcov_rf,vcov_rf_fs
mat list result // these would match the equation-by-equation regression or ivreg results.
 

*4
 
 
* first-stage
qui reg  treat_int_us  treat_int_dis_pre33 count_for td_* maind*  class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p
global dof = (e(N)-1)/(e(df_r)-1) // (N-1)/(N-K)
 
sureg (fs_mean:treat_int_us  treat_int_dis_pre33 count_for td_* maind*  class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p) ///
		(rf_mean: count_us  treat_int_dis_pre33  count_for td_* maind*  class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p)
 
mat suestb = e(b)
mat suestV = e(V) * $dof
output_tables "treat_int_dis_pre33" "treat_int_dis_pre33" 238
mat result = b_fs, vcov_fs,b_rf,vcov_rf,vcov_rf_fs
mat list result // these would match the equation-by-equation regression or ivreg results.

 

/******************************************************************************/
/***************    Productivity regs                **************************/
/******************************************************************************/

clear all
set matsize 800
set more off

use Datasets/inventors_panel_intensity.dta, clear

gen patenting=(inv_pat_num >0)

*** table 6
 
*xtivreg2 patenting (share_us = share_dis_pre33)  yrd*, fe i(inventor_id) cluster(maxmain)
capture reghdfe share_us  share_dis_pre33   yrd*, absorb(i.inventor_id)
 	global dof = (e(N)-1)/e(df_r)  
	

 
	foreach vv of varlist patenting share_us  share_dis_pre33  timefirst* timetofirst*  {
 		capture reghdfe `vv' yrd*, absorb(i.inventor_id)  residuals(p_`vv')

	}
		 
 	qui sureg (fs_mean: p_share_us  p_share_dis_pre33, nocons) ///
		(rf_mean:  p_patenting  p_share_dis_pre33 , nocons )  
	mat suestb = e(b)
	mat suestV = e(V)*$dof
 	
	global specid = 239
	output_tables "p_share_dis_pre33" "p_share_dis_pre33" 239

	
*xtivreg2 patenting (share_us = share_dis_pre33) timefirst* timetofirst* yrd*, fe i(inventor_id) cluster(maxmain)
 capture reghdfe share_us  share_dis_pre33   timefirst* timetofirst* yrd*, absorb(i.inventor_id)
 	global dof = (e(N)-1)/e(df_r)  
	

  
		 
 	qui sureg (fs_mean: p_share_us p_share_dis_pre33 p_timefirst* p_timetofirst* , nocons) ///
		(rf_mean:  p_patenting  p_share_dis_pre33 p_timefirst* p_timetofirst*, nocons )  
	mat suestb = e(b)
	mat suestV = e(V)*$dof
 	
	global specid = 240
	output_tables "p_share_dis_pre33" "p_share_dis_pre33" 240

 
XXXXX to be replicated; Table 9 does not have replication code

****** table 7
xtreg share_us share_dis_pre33 yrd*, cluster(maxmain) fe i(inventor_id)
outreg2 using table7.txt, replace
test share_dis_pre33=0
xtreg share_us share_dis_pre33 timefirst* timetofirst* yrd*, cluster(maxmain) fe i(inventor_id)
outreg2 using table7.txt, append
test share_dis_pre33=0
xtreg patenting share_dis_pre33  yrd*, cluster(maxmain) fe i(inventor_id)
outreg2 using table7.txt, append 
xtreg patenting share_dis_pre33 timefirst* timetofirst* yrd*, cluster(maxmain) fe i(inventor_id)
outreg2 using table7.txt, append

***** table 8
xtreg inv_pat_num share_us  yrd*, cluster(maxmain) fe i(inventor_id)
outreg2 using tableA4.txt, replace
xtreg inv_pat_num share_us timefirst* timetofirst* yrd*, cluster(maxmain) fe i(inventor_id)
outreg2 using tableA4.txt, append 
xtreg inv_pat_num share_dis_pre33  yrd*, cluster(maxmain) fe i(inventor_id)
outreg2 using tableA4.txt, append 
xtreg inv_pat_num share_dis_pre33 timefirst* timetofirst* yrd*, cluster(maxmain) fe i(inventor_id)
outreg2 using tableA4.txt, append
xtivreg2 inv_pat_num (share_us = share_dis_pre33)  yrd*, cluster(maxmain) fe i(inventor_id)
outreg2 using tableA4.txt, append 
xtivreg2 inv_pat_num (share_us = share_dis_pre33) timefirst* timetofirst* yrd*, cluster(maxmain) fe i(inventor_id)
outreg2 using tableA4.txt, append



******* Figure 5
cap log close
log using figures_data.log, append

cap gen patenting=(inv_pat_num >0)

gen group=1 if share_usinv<0.5
replace group=2 if share_usinv==0.5
replace group=3 if share_usinv>0.5 & share_usinv !=.

table gyear if group==1, contents(mean patenting)
table gyear if group==2, contents(mean patenting)
table gyear if group==3, contents(mean patenting)

drop group

******Figure 6

gen group=1 if share_disinv_pre33<0.5
replace group=2 if share_disinv_pre33==0.5
replace group=3 if share_disinv_pre33>0.5 & share_disinv_pre33 !=.

table gyear if group==1, contents(mean patenting)
table gyear if group==2, contents(mean patenting)
table gyear if group==3, contents(mean patenting)

log close

/******************************************************************************/
/***************    Entry regs                       **************************/
/******************************************************************************/

use entry_data.dta, clear

reg newinv treat_us td_* maind*  ,  cluster(main_nr)
outreg2 treat_us count_for using table9.txt, replace bdec(3)
reg newinv treat_us count_for class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p td_* maind* ,  cluster(main_nr)
outreg2 treat_us count_for class_age* using table9.txt, append bdec(3)
reg newinv_total treat_us  td_* maind* ,  cluster(main_nr)
outreg2 treat_us count_for using table9.txt, append bdec(3)
reg newinv_total treat_us count_for class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p td_* maind* , cluster(main_nr)
outreg2 treat_us count_for using table9.txt, append bdec(3)
ivreg newinv (treat_us = treat_dis_pre33) td_* maind*  , cluster(main_nr)
outreg2 treat_us  count_for  using table9.txt, append bdec(3)
ivreg newinv (treat_us = treat_dis_pre33) count_for td_* maind*  class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p, cluster(main_nr)
outreg2 treat_us count_for using table9.txt, append bdec(3)
ivreg newinv_total (treat_us = treat_dis_pre33) td_* maind*  , cluster(main_nr)
outreg2 treat_us  count_for  using table9.txt, append bdec(3)
ivreg newinv_total (treat_us = treat_dis_pre33) count_for td_* maind*  class_age* totpool_ind14 totpool_ind58 totpool_ind912 totpool_ind1316 totpool_ind17p, cluster(main_nr)
outreg2 treat_us count_for using table9.txt, append bdec(3)

cap log close
log using figures_data.log, append

***Figure 7
bys main: egen evertreat_us=max(treat_us)
table gyear if evertreat_us==1, contents(mean newinv)
table gyear if evertreat_us==0, contents(mean newinv)

***Figure 8
bys main: egen evertreat_dis=max(treat_dis_pre33)
table gyear if evertreat_dis==1, contents(mean newinv)
table gyear if evertreat_dis==0, contents(mean newinv)



log close


