use "ACCOSI_AER_DATA_MAFIA_PUBLIC_SPENDING.dta", clear
tsset Id Year
********************
*Mean Difference
********************
gen Split_CD_NoCD=2 if Year>=1989 & Year<=1999
replace Split_CD_NoCD=1 if CD>0
gen LSplit_CD_NoCD=l.Split_CD_NoCD
*
gen Province_CD= (Province=="AGRIGENTO" | Province=="AVELLINO" | Province=="BARI" | Province=="BENEVENTO" | Province=="CALTANISSETTA" | Province=="CASERTA" | Province=="CATANIA" | Province=="CATANZARO" | Province=="LECCE" | Province=="MATERA" | Province=="MESSINA" | Province=="NAPOLI" | Province=="PALERMO" | Province=="RAGUSA" | Province=="REGGIO_CALABRIA" | Province=="SALERNO" | Province=="TORINO" | Province=="TRAPANI")
*
ttest Gprop if Year>=1990 & Year<=1999, by(LSplit_CD_NoCD) unequal
ttest G if Year>=1990 & Year<=1999, by(LSplit_CD_NoCD) unequal
ttest Gprop if Year>=1990 & Year<=1999 & Province_CD==1, by(LSplit_CD_NoCD) unequal
ttest G if Year>=1990 & Year<=1999 & Province_CD==1, by(LSplit_CD_NoCD) unequal
ttest Gprop if Year>=1990 & Year<=1999 & LSplit_CD_NoCD==2, by(Province_CD) unequal
ttest G if Year>=1990 & Year<=1999 & LSplit_CD_NoCD==2, by(Province_CD) unequal
*
drop Split_CD_NoCD LSplit_CD_NoCD Province_CD
********************
*Randomness
********************
quietly {
gen FirstCD91=  (Province=="NAPOLI" | Province=="CASERTA" | Province=="LECCE" | Province=="CATANZARO" | Province=="REGGIO_CALABRIA" | Province=="PALERMO" | Province=="MESSINA" | Province=="CATANIA") & Year<=1990
gen FirstCD92= (Province=="TRAPANI" | Province=="CALTANISSETTA" | Province=="RAGUSA" | Province=="AGRIGENTO") & Year<=1991
gen FirstCD93= (Province=="BARI" | Province=="AVELLINO" | Province=="SALERNO") & Year<=1992
gen FirstCD94= (Province=="MATERA" | Province=="BENEVENTO") & Year<=1993
gen FirstCD95= (Province=="TORINO") & Year<=1994
*
gen Trend=Year-1985
gen TrendFirstCD91=FirstCD91*Trend
gen TrendFirstCD92=FirstCD92*Trend
gen TrendFirstCD93=FirstCD93*Trend
gen TrendFirstCD94=FirstCD94*Trend
gen TrendFirstCD95=FirstCD95*Trend
*
gen AllTrendFirstCD=TrendFirstCD91+TrendFirstCD92+TrendFirstCD93+TrendFirstCD94+TrendFirstCD95
gen AllFirstCD=FirstCD91+FirstCD92+FirstCD93+FirstCD94+FirstCD95
*
label var AllFirstCD "Before First CD Dummy"
label var AllTrendFirstCD "Before First CD Trend"
*
eststo: reg Y Trend AllFirstCD AllTrendFirstCD , cluster(Group)
}
*
esttab est1, keep(AllFirstCD AllTrendFirstCD) b(2) se label
drop First* Trend* All*
est clear
quietly {
********************
*Generate Regressors
********************
foreach j in G Y U1 U2 Mafiosi Extortion Corruption1 Corruption2 Murder {
g L1`j'=L1.`j'
g L2`j'=L2.`j'
}
*
gen L2CD=L2.CD
gen L3CD=L3.CD
gen L1CD_S2=L.CD_S2
*
foreach j in Resignation Election Budget Others G_ex {
g L1`j'=L.`j'
}
*
summarize L1G if Year>=1990 & Year<=1999, meanonly
local L1Gmean = r(mean)
summarize L1G_ex if Year>=1990 & Year<=1999, meanonly
local L1G_exmean = r(mean)
g L1Gint=(L1G-`L1Gmean')*(L1G_ex-`L1G_exmean')
*
foreach j in G Y CD U1 U2 Mafiosi Extortion Corruption1 Corruption2 Murder ///
L1G L1Y L1CD L1U1 L1U2 L1Mafiosi L1Extortion L1Corruption1 L1Corruption2 L1Murder ///
L2G L2Y L2CD L2U1 L2U2 L2Mafiosi L2Extortion L2Corruption1 L2Corruption2 L2Murder ///
Resignation Election Budget Others L1Resignation L1Election L1Budget L1Others ///
L2CD L3CD CD_S1 L1CD_S2 ///
G_ex L1G_ex L1Gint {
xi: regress `j' i.Year i.Id if Year>=1990 & Year<=1999
predict temporaneo, residuals
replace `j'=temporaneo
drop temporaneo
}
drop _IYear*
drop _IId*
*
lab var Province "Province"
lab var Region "Region"
lab var Year "Year"
lab var Group "Cluster"
*
lab var G "G(t)"
lab var L1G "G(t-1)"
lab var L2G "G(t-2)"
lab var L1Y "Y(t-1)"
lab var L2Y "Y(t-2)"
lab var CD_S1 "CD-S1"
lab var L1CD_S2 "CD-S2(t-1)"
*
label variable Resignation "Resignation(t)"
label variable L1Resignation "Resignation(t-1)"
label variable Election "Election(t)"
label variable L1Election "Election(t-1)"
label variable Budget "Budget-No confidence vote(t)"
label variable L1Budget "Budget-No confidence vote(t-1)"
label variable Others "Others(t)"
label variable L1Others "Others(t-1)"
}
********************
*Baseline
********************
 
capture program drop output_tables
program output_tables
	args  exexog1 exexogk specid 
{
	
	global exexog1 "`exexog1'" // first excluded exogenous variable
	global exexogk "`exexogk'" // last excluded exogenous variable
	 
	local b_fs_start = colnumb(suestb,"fs_mean:$exexog1")
	local b_fs_end = colnumb(suestb,"fs_mean:$exexogk")
	local b_rf_start = colnumb(suestb,"rf_mean:$exexog1")
	local b_rf_end = colnumb(suestb,"rf_mean:$exexogk")

	local vcov_fs_start = colnumb(suestV,"fs_mean:$exexog1")
	local vcov_fs_end = colnumb(suestV,"fs_mean:$exexogk")
	local vcov_rf_start = colnumb(suestV,"rf_mean:$exexog1")
	local vcov_rf_end = colnumb(suestV,"rf_mean:$exexogk")

	mat b_fs = suestb[1,`b_fs_start'..`b_fs_end']
	mat vcov_fs = suestV[`vcov_fs_start'..`vcov_fs_end',`vcov_fs_start'..`vcov_fs_end']
	mat b_rf = suestb[1,`b_rf_start'..`b_rf_end']
	mat vcov_rf = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_rf_start'..`vcov_rf_end']
	mat vcov_rf_fs = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_fs_start'..`vcov_fs_end']
 
	mat b = b_fs, b_rf
	mat list b // these would match the equation-by-equation regression results.
	mat2txt, matrix(b) saving(b_`specid') replace  // export with specification id

	mat vcov = vcov_fs, vcov_rf_fs' \ vcov_rf_fs , vcov_rf
	mat list vcov // these would match the equation-by-equation regression results.
	mat2txt, matrix(vcov) saving(vcov_`specid')  replace
	
	qui count if ivsample == 1
	global N = r(N)
	mat accum ZZ = $exexog1 - $exexogk if ivsample, nocons
	mat ZZ = ZZ/$N
	mat2txt, matrix(ZZ) saving(ZZ_`specid')  replace
 
 
 
}
end
 

global Controls L1U1 L1U2 L2U1 L2U2 L2CD L3CD Mafiosi Extortion Corruption1 Corruption2 Murder L1Mafiosi L1Extortion L1Corruption1 L1Corruption2 L1Murder L2Mafiosi L2Extortion L2Corruption1 L2Corruption2 L2Murder


* Table 4 (2)
*ivreg2 Y (G = CD_S1 L1CD_S2) L1G L2G `Controls' [w=Pop] if Year>=1990 & Year<=1999, first partial(`Controls') cluster(Group)

* Table 4 (3)
*ivreg2 Y (G = CD_S1 L1CD_S2) L1G L2G L1Y L2Y $Controls [w=Pop] if Year>=1990 & Year<=1999, first partial($Controls) cluster(Group)




 // so manually weight
foreach vv of varlist  * {
	gen `vv'_p = `vv'*sqrt(Population)
}
gen cons_p = sqrt(Population)
global Controls L1U1_p L1U2_p L2U1_p L2U2_p L2CD_p L3CD_p Mafiosi_p Extortion_p Corruption1_p Corruption2_p Murder_p L1Mafiosi_p L1Extortion_p L1Corruption1_p L1Corruption2_p L1Murder_p L2Mafiosi_p L2Extortion_p L2Corruption1_p L2Corruption2_p L2Murder_p
 

* Table 4 (2)
reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p   $Controls cons_p  if Year>=1990 & Year<=1999, nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)

ivreg2 Y_p (G_p = CD_S1_p L1CD_S2_p) L1G_p L2G_p   $Controls  cons_p if Year>=1990 & Year<=1999, nocons first partial($Controls) cluster(Group)

gen ivsample = e(sample)

global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p

preserve

foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	regress `vv' L1G_p L2G_p   $Controls cons_p  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"
output_tables  $exexog1_adj $exexogk_adj 125

restore

* Table 4 (3)
reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p L1Y_p L2Y_p $Controls cons_p  if Year>=1990 & Year<=1999, nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)

ivreg2 Y_p (G_p = CD_S1_p L1CD_S2_p) L1G_p L2G_p L1Y_p L2Y_p $Controls  cons_p if Year>=1990 & Year<=1999, nocons first partial($Controls) cluster(Group)
capture drop ivsample
gen ivsample = e(sample)

global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p

preserve

foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	regress `vv' L1G_p L2G_p L1Y_p L2Y_p $Controls cons_p  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"
output_tables  $exexog1_adj $exexogk_adj 126

restore

*Table 5 (1)
ivreg2 Y (G = CD_S1 L1CD_S2) L1G L2G L1Y L2Y L2CD L3CD L1U1 L1U2 L2U1 L2U2 [w=Population] ///
if Year>=1990 & Year<=1999, first partial(L2CD L3CD L1U1 L1U2 L2U1 L2U2) cluster(Group)

reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p L1Y_p L2Y_p L2CD_p L3CD_p L1U1_p L1U2_p L2U1_p L2U2_p cons_p  if Year>=1990 & Year<=1999, nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)

ivreg2 Y_p (G_p = CD_S1_p L1CD_S2_p) L1G_p L2G_p L1Y_p L2Y_p L2CD_p L3CD_p L1U1_p L1U2_p L2U1_p L2U2_p cons_p if Year>=1990 & Year<=1999, nocons first partial(L2CD_p L3CD_p L1U1_p L1U2_p L2U1_p L2U2_p cons_p) cluster(Group)
capture drop ivsample
gen ivsample = e(sample)

global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p

preserve

foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	regress `vv' L1G_p L2G_p L1Y_p L2Y_p L2CD_p L3CD_p L1U1_p L1U2_p L2U1_p L2U2_p cons_p if Year>=1990 & Year<=1999 & ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"
output_tables  $exexog1_adj $exexogk_adj 127

restore

**Table 5 (2) - (5)
local counter = 0
foreach j in Resignation Election Budget Others {
local Controls L1U1_p L1U2_p L2U1_p L2U2_p L2CD_p L3CD_p Mafiosi_p Extortion_p Corruption1_p Corruption2_p Murder_p L1Mafiosi_p L1Extortion_p L1Corruption1_p L1Corruption2_p L1Murder_p L2Mafiosi_p L2Extortion_p L2Corruption1_p L2Corruption2_p L2Murder_p

qui reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p L1Y_p L2Y_p `Controls' `j'_p L1`j'_p cons_p if Year>=1990 & Year<=1999, nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)

*
ivreg2 Y_p (G_p = CD_S1_p L1CD_S2_p) L1G_p L2G_p L1Y_p L2Y_p `Controls' `j'_p L1`j'_p cons_p ///
if Year>=1990 & Year<=1999, first partial(`Controls') cluster(Group) nocons

capture drop ivsample
gen ivsample = e(sample)

global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p

preserve

foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	qui regress `vv' L1G_p L2G_p L1Y_p L2Y_p `Controls' `j'_p L1`j'_p cons_p  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"
global specid = 128 + `counter'
output_tables  $exexog1_adj $exexogk_adj $specid
local ++counter

restore

}

* Table 6 (1)
local Controls L1U1 L1U2 L2U1 L2U2 L2CD L3CD Mafiosi Extortion Corruption1 Corruption2 Murder L1Mafiosi L1Extortion L1Corruption1 L1Corruption2 L1Murder L2Mafiosi L2Extortion L2Corruption1 L2Corruption2 L2Murder
*
ivreg2 Y (G = CD_S1 L1CD_S2) L1G L2G L1Y L2Y G_ex L1G_ex `Controls' [w=Population] if Year>=1990 & Year<=1999, first partial(`Controls') cluster(Group)

global Controls L1U1_p L1U2_p L2U1_p L2U2_p L2CD_p L3CD_p Mafiosi_p Extortion_p Corruption1_p Corruption2_p Murder_p L1Mafiosi_p L1Extortion_p L1Corruption1_p L1Corruption2_p L1Murder_p L2Mafiosi_p L2Extortion_p L2Corruption1_p L2Corruption2_p L2Murder_p
  
qui reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p  L1Y_p L2Y_p G_ex_p L1G_ex_p $Controls cons_p  if Year>=1990 & Year<=1999, nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)

ivreg2 Y_p (G_p = CD_S1_p L1CD_S2_p) L1G_p L2G_p L1Y_p L2Y_p G_ex_p L1G_ex_p  $Controls  cons_p if Year>=1990 & Year<=1999, nocons first partial($Controls) cluster(Group)
capture drop ivsample
gen ivsample = e(sample)

global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p

preserve

foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	qui regress `vv' L1G_p L2G_p L1Y_p L2Y_p G_ex_p L1G_ex_p  $Controls cons_p  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"
output_tables  $exexog1_adj $exexogk_adj 132

restore

* Table 6 (2)
local Controls L1U1 L1U2 L2U1 L2U2 L2CD L3CD Mafiosi Extortion Corruption1 Corruption2 Murder L1Mafiosi L1Extortion L1Corruption1 L1Corruption2 L1Murder L2Mafiosi L2Extortion L2Corruption1 L2Corruption2 L2Murder

ivreg2 Y (G = CD_S1 L1CD_S2) L1G L2G L1Y L2Y L1Gint `Controls' [w=Population] if Year>=1990 & Year<=1999, first partial(`Controls') cluster(Group)

global Controls L1U1_p L1U2_p L2U1_p L2U2_p L2CD_p L3CD_p Mafiosi_p Extortion_p Corruption1_p Corruption2_p Murder_p L1Mafiosi_p L1Extortion_p L1Corruption1_p L1Corruption2_p L1Murder_p L2Mafiosi_p L2Extortion_p L2Corruption1_p L2Corruption2_p L2Murder_p
  
qui reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p  L1Y_p L2Y_p L1Gint_p $Controls cons_p  if Year>=1990 & Year<=1999, nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)

ivreg2 Y_p (G_p = CD_S1_p L1CD_S2_p) L1G_p L2G_p L1Y_p L2Y_p L1Gint_p $Controls  cons_p if Year>=1990 & Year<=1999, nocons first partial($Controls) cluster(Group)
capture drop ivsample
gen ivsample = e(sample)

global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p

preserve

foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	qui regress `vv' L1G_p L2G_p L1Y_p L2Y_p L1Gint_p $Controls cons_p  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"
output_tables  $exexog1_adj $exexogk_adj 133

restore

*Table 7 (1) - (7)
local counter = 0
foreach j in NAPOLI CASERTA PALERMO CATANIA SALERNO BARI REGGIO_CALABRIA {
local Controls L1U1_p L1U2_p L2U1_p L2U2_p L2CD_p L3CD_p Mafiosi_p Extortion_p Corruption1_p Corruption2_p Murder_p L1Mafiosi_p L1Extortion_p L1Corruption1_p L1Corruption2_p L1Murder_p L2Mafiosi_p L2Extortion_p L2Corruption1_p L2Corruption2_p L2Murder_p

preserve
drop if Province=="`j'"

qui reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p L1Y_p L2Y_p `Controls'  cons_p if Year>=1990 & Year<=1999, nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)

*
ivreg2 Y_p (G_p = CD_S1_p L1CD_S2_p) L1G_p L2G_p L1Y_p L2Y_p `Controls'  cons_p ///
if Year>=1990 & Year<=1999, first partial(`Controls') cluster(Group) nocons

capture drop ivsample
gen ivsample = e(sample)

global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p


foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	qui regress `vv' L1G_p L2G_p L1Y_p L2Y_p `Controls'  cons_p  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"
global specid = 135 + `counter'
output_tables  $exexog1_adj $exexogk_adj $specid
dis $specid
local ++counter

restore

}

*
 

********************
*Further Results Table 8 (1) - (3)
********************
*
 
*
ivreg2 Y (G = CD_S1 L1CD_S2) L1G L2G L1Y L2Y `Controls' [w=Pop] ///
if Year>=1990 & Year<=1999 & (Region=="ABRUZZO" | Region=="MOLISE" | Region=="CAMPANIA" | Region=="PUGLIA" | Region=="BASILICATA" | Region=="CALABRIA" | Region=="SICILIA" | Region=="SARDEGNA"), first partial(`Controls') cluster(Group)

local Controls L1U1_p L1U2_p L2U1_p L2U2_p L2CD_p L3CD_p Mafiosi_p Extortion_p Corruption1_p Corruption2_p Murder_p L1Mafiosi_p L1Extortion_p L1Corruption1_p L1Corruption2_p L1Murder_p L2Mafiosi_p L2Extortion_p L2Corruption1_p L2Corruption2_p L2Murder_p

preserve

qui reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p L1Y_p L2Y_p `Controls'  cons_p ///
 if Year>=1990 & Year<=1999 & (Region=="ABRUZZO" | Region=="MOLISE" | Region=="CAMPANIA" | Region=="PUGLIA" | Region=="BASILICATA" | Region=="CALABRIA" | Region=="SICILIA" | Region=="SARDEGNA"), /// 
 nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)

*
ivreg2 Y_p (G_p = CD_S1_p L1CD_S2_p) L1G_p L2G_p L1Y_p L2Y_p `Controls'  cons_p ///
 if Year>=1990 & Year<=1999 & (Region=="ABRUZZO" | Region=="MOLISE" | Region=="CAMPANIA" | Region=="PUGLIA" | Region=="BASILICATA" | Region=="CALABRIA" | Region=="SICILIA" | Region=="SARDEGNA"), /// 
 first partial(`Controls') cluster(Group) nocons   

capture drop ivsample
gen ivsample = e(sample)

global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p


foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	qui regress `vv' L1G_p L2G_p L1Y_p L2Y_p `Controls'  cons_p  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if Year>=1990 & Year<=1999 & ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"

output_tables  $exexog1_adj $exexogk_adj 142
 
restore

************ Table 8 (2)

quietly {
use "ACCOSI_AER_DATA_MAFIA_PUBLIC_SPENDING.dta", clear
tsset Id Year
foreach j in G Y U1 U2 Mafiosi Extortion Corruption1 Corruption2 Murder {
g L1`j'=L1.`j'
g L2`j'=L2.`j'
}
gen L2CD=L2.CD
gen L3CD=L3.CD
gen L1CD_S2=L.CD_S2
*
foreach j in G Y CD U1 U2 Mafiosi Extortion Corruption1 Corruption2 Murder ///
L1G L1Y L1CD L1U1 L1U2 L1Mafiosi L1Extortion L1Corruption1 L1Corruption2 L1Murder ///
L2G L2Y L2CD L2U1 L2U2 L2Mafiosi L2Extortion L2Corruption1 L2Corruption2 L2Murder ///
L2CD L3CD CD_S1 L1CD_S2 {
xi: regress `j' i.Id if Year>=1990 & Year<=1999
predict temporaneo, residuals
replace `j'=temporaneo
drop temporaneo
}
drop _IId*
lab var G "G(t)"
lab var L1G "G(t-1)"
lab var L2G "G(t-2)"
lab var L1Y "Y(t-1)"
lab var L2Y "Y(t-2)"
foreach vv of varlist  * {
	gen `vv'_p = `vv'*sqrt(Population)
}
gen cons_p = sqrt(Population)
}
*

local Controls L1U1 L1U2 L2U1 L2U2 L2CD L3CD Mafiosi Extortion Corruption1 Corruption2 Murder L1Mafiosi L1Extortion L1Corruption1 L1Corruption2 L1Murder L2Mafiosi L2Extortion L2Corruption1 L2Corruption2 L2Murder
*
xi: ivreg2 Y (G = CD_S1 L1CD_S2) L1G L2G L1Y L2Y `Controls' [w=Population] ///
if Year>=1990 & Year<=1999, first partial(`Controls') cluster(Group)
capture drop ivsample
gen ivsample = e(sample)

global Controls L1U1_p L1U2_p L2U1_p L2U2_p L2CD_p L3CD_p Mafiosi_p Extortion_p Corruption1_p Corruption2_p Murder_p L1Mafiosi_p L1Extortion_p L1Corruption1_p L1Corruption2_p L1Murder_p L2Mafiosi_p L2Extortion_p L2Corruption1_p L2Corruption2_p L2Murder_p
 
ivreg2 Y_p (G_p = CD_S1_p L1CD_S2_p) L1G_p L2G_p L1Y_p L2Y_p $Controls   cons_p if ivsample==1, first partial($Controls ) cluster(Group) nocons   

preserve

qui reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p L1Y_p L2Y_p $Controls cons_p ///
 if ivsample == 1, /// 
 nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)


global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p


foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	qui regress `vv' L1G_p L2G_p L1Y_p L2Y_p $Controls  cons_p  if  ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if   ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if  ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"

output_tables  $exexog1_adj $exexogk_adj 143
 
restore

************
quietly {
use "ACCOSI_AER_DATA_MAFIA_PUBLIC_SPENDING.dta", clear
tsset Id Year
foreach j in G Y U1 U2 Mafiosi Extortion Corruption1 Corruption2 Murder {
g L1`j'=L1.`j'
g L2`j'=L2.`j'
}
gen L2CD=L2.CD
gen L3CD=L3.CD
gen L1CD_S2=L.CD_S2
*
foreach j in G Y CD U1 U2 Mafiosi Extortion Corruption1 Corruption2 Murder ///
L1G L1Y L1CD L1U1 L1U2 L1Mafiosi L1Extortion L1Corruption1 L1Corruption2 L1Murder ///
L2G L2Y L2CD L2U1 L2U2 L2Mafiosi L2Extortion L2Corruption1 L2Corruption2 L2Murder ///
L2CD L3CD CD_S1 L1CD_S2 {
xi: regress `j' i.Year if Year>=1990 & Year<=1999
predict temporaneo, residuals
replace `j'=temporaneo
drop temporaneo
}
drop _IYear*
lab var G "G(t)"
lab var L1G "G(t-1)"
lab var L2G "G(t-2)"
lab var L1Y "Y(t-1)"
lab var L2Y "Y(t-2)"
*
foreach vv of varlist  * {
	gen `vv'_p = `vv'*sqrt(Population)
}
gen cons_p = sqrt(Population)
}

local Controls L1U1 L1U2 L2U1 L2U2 L2CD L3CD Mafiosi Extortion Corruption1 Corruption2 Murder L1Mafiosi L1Extortion L1Corruption1 L1Corruption2 L1Murder L2Mafiosi L2Extortion L2Corruption1 L2Corruption2 L2Murder
*
xi: ivreg2 Y (G = CD_S1 L1CD_S2) L1G L2G L1Y L2Y `Controls' [w=Population] ///
if Year>=1990 & Year<=1999, first partial(`Controls') cluster(Group)
 
capture drop ivsample
gen ivsample = e(sample)

global Controls L1U1_p L1U2_p L2U1_p L2U2_p L2CD_p L3CD_p Mafiosi_p Extortion_p Corruption1_p Corruption2_p Murder_p L1Mafiosi_p L1Extortion_p L1Corruption1_p L1Corruption2_p L1Murder_p L2Mafiosi_p L2Extortion_p L2Corruption1_p L2Corruption2_p L2Murder_p
 
preserve

qui reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p L1Y_p L2Y_p $Controls cons_p ///
 if ivsample == 1, /// 
 nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)


global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p


foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	qui regress `vv' L1G_p L2G_p L1Y_p L2Y_p $Controls  cons_p  if  ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if   ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if  ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"

output_tables  $exexog1_adj $exexogk_adj 144
 
restore
*Table 6 (3)
********************
*Spillover Aggregation
********************
use "ACCOSI_AER_AGGDATA_MAFIA_PUBLIC_SPENDING", clear
quietly {
tsset Id Year
foreach j in G Y U1 U2 Mafiosi Extortion Corruption1 Corruption2 Murder {
g L1`j'=L1.`j'
g L2`j'=L2.`j'
}
gen L2CD=L2.CD
gen L3CD=L3.CD
gen L1CD_S2=L.CD_S2
foreach j in G Y CD U1 U2 Mafiosi Extortion Corruption1 Corruption2 Murder ///
L1G L1Y L1CD L1U1 L1U2 L1Mafiosi L1Extortion L1Corruption1 L1Corruption2 L1Murder ///
L2G L2Y L2CD L2U1 L2U2 L2Mafiosi L2Extortion L2Corruption1 L2Corruption2 L2Murder ///
L2CD L3CD CD_S1 L1CD_S2 {
xi: regress `j' i.Year i.Id if Year>=1990 & Year<=1999
predict temporaneo, residuals
replace `j'=temporaneo
drop temporaneo
}
*
lab var G "G(t)"
lab var L1G "G(t-1)"
lab var L2G "G(t-2)"
lab var L1Y "Y(t-1)"
lab var L2Y "Y(t-2)"
*
foreach vv of varlist  * {
	gen `vv'_p = `vv'*sqrt(Population)
}
gen cons_p = sqrt(Population)
}

global Controls L1U1_p L1U2_p L2U1_p L2U2_p L2CD_p L3CD_p Mafiosi_p Extortion_p Corruption1_p Corruption2_p Murder_p L1Mafiosi_p L1Extortion_p L1Corruption1_p L1Corruption2_p L1Murder_p L2Mafiosi_p L2Extortion_p L2Corruption1_p L2Corruption2_p L2Murder_p
 
local Controls L1U1 L1U2 L2U1 L2U2 L2CD L3CD Mafiosi Extortion Corruption1 Corruption2 Murder L1Mafiosi L1Extortion L1Corruption1 L1Corruption2 L1Murder L2Mafiosi L2Extortion L2Corruption1 L2Corruption2 L2Murder
ivreg2 Y (G = CD_S1 L1CD_S2) L1G L2G L1Y L2Y `Controls' [w=Population] if Year>=1990 & Year<=1999, first partial(`Controls') cluster(Group)

preserve

qui reg G_p CD_S1_p L1CD_S2_p L1G_p L2G_p L1Y_p L2Y_p $Controls cons_p ///
 if Year>=1990 & Year<=1999 , /// 
 nocons  cluster(Group)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)

*
ivreg2 Y_p (G_p = CD_S1_p L1CD_S2_p) L1G_p L2G_p L1Y_p L2Y_p $Controls   cons_p ///
 if Year>=1990 & Year<=1999 , /// 
 first partial($Controls ) cluster(Group) nocons   

capture drop ivsample
gen ivsample = e(sample)

global exexog1 "CD_S1_p" 
global exexogk "L1CD_S2_p"
order CD_S1_p L1CD_S2_p


foreach vv of varlist Y_p G_p $exexog1- $exexogk {
	qui regress `vv' L1G_p L2G_p L1Y_p L2Y_p $Controls  cons_p  if  ivsample==1, nocons   
	predict `vv'_adj, residual
}

estimates clear
qui  reg G_p_adj CD_S1_p_adj L1CD_S2_p_adj  if   ivsample==1, nocons   
estimates store fs
qui  reg Y_p_adj CD_S1_p_adj L1CD_S2_p_adj  if  ivsample==1, nocons 
estimates store rf

qui suest fs rf, vce(cluster Group)
global m = e(N_clust) // number of clusters
mat suestb = e(b)
mat suestV = e(V) * $dof

global exexog1_adj "CD_S1_p_adj" 
global exexogk_adj "L1CD_S2_p_adj"

output_tables  $exexog1_adj $exexogk_adj 134
 
restore
