/* Include file for regressions */
 
/* FIRST STAGE REGRESSION */
qui regress gradcap ${inst_set} ${control_vars} [pweight=slwt], vce(cluster yob_bplg)
global N = e(N)
global K = e(df_m)
global dof = ($N-1)/($N-$K) // (N-1)/(N-K)

/* Implement 2SLS using Frisch-Waugh-Lovell Theorem */
capture drop ${outcomev}_adj gradcap_adj ${inst_set_adj}
/* First regress outcome, gradcap, and instruments on remaining regressors */
foreach X of varlist $outcomev gradcap $inst_set {
    quietly regress `X' ${control_vars} [pweight=slwt], vce(cluster yob_bplg) 
    predict `X'_adj if e(sample), resid
   } 



global outcomev_adj ${outcomev}_adj
foreach X of varlist $outcomev_adj gradcap_adj $inst_set_adj {
	capture drop `X'_adj
    qui replace `X' = `X'*sqrt(slwt) 
    qui regress `X' cons_p, nocons 
    predict `X'_adj if e(sample), resid 
    replace `X' = `X'_adj 
   } 

/* 2SLS */
 

qui reg ${outcomev}_adj ${inst_set_adj} , nocons  
estimates store rf
qui reg gradcap_adj ${inst_set_adj} , nocons  
estimates store fs

qui suest fs rf, vce(cluster yob_bplg)
global m = e(N_clust) 
mat suestb = e(b)
mat suestV = e(V) * $dof  

global exog1 "ny7_adj" 
global exogp "ny9_adj" 

local b_fs_start = colnumb(suestb,"fs_mean:$exog1")
local b_fs_end = colnumb(suestb,"fs_mean:$exogp")
local b_rf_start = colnumb(suestb,"rf_mean:$exog1")
local b_rf_end = colnumb(suestb,"rf_mean:$exogp")

local vcov_fs_start = colnumb(suestV,"fs_mean:$exog1")
local vcov_fs_end = colnumb(suestV,"fs_mean:$exogp")
local vcov_rf_start = colnumb(suestV,"rf_mean:$exog1")
local vcov_rf_end = colnumb(suestV,"rf_mean:$exogp")
 

mat b_fs = suestb[1,`b_fs_start'..`b_fs_end']
mat vcov_fs = suestV[`vcov_fs_start'..`vcov_fs_end',`vcov_fs_start'..`vcov_fs_end']
mat b_rf = suestb[1,`b_rf_start'..`b_rf_end']
mat vcov_rf = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_rf_start'..`vcov_rf_end']
mat vcov_rf_fs = suestV[`vcov_rf_start'..`vcov_rf_end',`vcov_fs_start'..`vcov_fs_end']

mat b = b_fs, b_rf
mat list b 
mat2txt, matrix(b) saving(b_$specid) replace  

mat vcov = vcov_fs, vcov_rf_fs' \ vcov_rf_fs , vcov_rf
mat list vcov 
mat2txt, matrix(vcov) saving(vcov_$specid)  replace

mat accum ZZ = $exog1-$exogp, nocons
mat ZZ = ZZ/$N
mat2txt, matrix(ZZ) saving(ZZ_$specid)  replace
