/**********************************************************************************************
	* Replication code for "Credit Supply and the Price of Housing", American Economic Review
	*
	* Distributed under copyright, Giovanni Favara and Jean Imbs, 2014 and the American 
	* Economic Association, 2014
	*
	* This code creates Tables 1-6 and Figure 1-4 in the Paper, as well as Tables A1-A4 
	* in the Paper Appendix, and Tables OA2-OA8 in the on line web Appendix
	***********************************************************************************************/ 
	
	
	** Define working directory 
	clear all
	global 		main    "/cm/giovanni/Final_AER2"
	global 		data    "."
	global 		dofiles "$main/dofiles"
	global 		output  "$main/output"

	
	** load data 
	 
	use "$data/hmda.dta", clear
	merge 1:1 county year using "$data/hp_dereg_controls.dta", nogen keep(1 3)
	merge 1:1 county year using "$data/call.dta", nogen keep(1 3)
	
	** define controls 
	global D_control       "Dl_inc LDl_inc Dl_pop LDl_pop Dl_hpi LDl_hpi Dl_her_v LDl_her_v"
	global D_control_hp    "Dl_inc LDl_inc Dl_pop LDl_pop Dl_her_v LDl_her_v"
	global B_control        " etoa_b liatoa_b totltoa_b "
	tab county, gen(county_)
	
	
capture program drop  avar_replicated	
program avar_replicated
	args  endo specid
	{
	tempvar fs_sample e1 e2
	qui xtivreg2 Dl_hpi (`endo' = Linter_bra) LDl_hpi  $D_control_hp yryear_1994-yryear_2005 [aw=w1], fe r bw(3) partial(yryear_1994-yryear_2005 )   
	gen `fs_sample' = e(sample)

	capture reghdfe `endo'  Linter_bra LDl_hpi  $D_control_hp  [aw=w1]  if `fs_sample' == 1, vce(robust, bw(3))  absorb(yryear_1994-yryear_2005 county_1-county_1048) residuals(`e1')
		global dof = e(N)/e(df_r)
		global N = e(N)
	mat b = e(b)
	mat V = e(V)
	mat fs_b = b[1,"Linter_bra"]
	mat fs_v = V["Linter_bra","Linter_bra"]

	capture reghdfe Dl_hpi   Linter_bra LDl_hpi  $D_control_hp  [aw=w1]  if `fs_sample' == 1, vce(robust, bw(3))  absorb(yryear_1994-yryear_2005 county_1-county_1048) residuals(`e2')
	mat V = e(V)
	mat b = e(b)
	mat rf_b = b[1,"Linter_bra"]
	mat rf_v = V["Linter_bra","Linter_bra"]
	
	capture drop *_p
 	foreach vv of varlist Dl_hpi `endo' Linter_bra    {
		capture reghdfe `vv' LDl_hpi  $D_control_hp  [aw=w1]  if `fs_sample' == 1, absorb(yryear_1994-yryear_2005 county_1-county_1048) residuals(`vv'_p)
	}
	qui reg `endo'_p  Linter_bra_p  [aw=w1] , nocon
	mat rep_fs_b = e(b)
	qui reg Dl_hpi_p  Linter_bra_p  [aw=w1] , nocon
	mat rep_rf_b = e(b)
	
	mat accum XX = Linter_bra_p [aw=w1] if `fs_sample'==1, nocons
	mat Sxx=XX*1/$N
	mat Sxxi = syminv(Sxx)
	qui avar (`e1' `e2') (Linter_bra_p  ) [aw=w1] if `fs_sample' ==1, robust bw(3) nocons  

	mat S=r(S)
	mat S = S*$dof
	mat S1=S[1,1]
	mat S2=S[2,2]
	mat S12=S[2,1 ]
 
 	mat V1 = Sxxi*S1*Sxxi*1/r(N)
 	mat V2 = Sxxi*S2*Sxxi*1/r(N)
	mat V12 = Sxxi*S12*Sxxi*1/r(N)
 	
	mat replicated = fs_b, rep_fs_b, rf_b, rep_rf_b ,V1, fs_v, V2 , rf_v 
	mat list replicated

	mat b = fs_b, rf_b 
	mat2txt, matrix(b) saving(b_`specid') replace  // export with specification id

	mat vcov = fs_v, V12 \ V12 ,  rf_v 
	mat2txt, matrix(vcov) saving(vcov_`specid')  replace 	
	}
end
	***********************************************************************************************
	**       TABLE   5          								     **
	***********************************************************************************************
	// for replication, first partial out fixed effects and exogenous variables

		
	** TABLE 5 (1)  
	xtivreg2 Dl_hpi (Dl_nloans_b = Linter_bra) LDl_hpi  $D_control_hp yryear_1994-yryear_2005 [aw=w1], fe r bw(3) partial(yryear_1994-yryear_2005 )  first
 	avar_replicated Dl_nloans_b 108
	** Table 5 (2)
	xtivreg2 Dl_hpi (Dl_vloans_b = Linter_bra) LDl_hpi  $D_control_hp yr* [aw=w1], fe r bw(3) partial(yr*) first 
 	avar_replicated Dl_vloans_b  109
	
	** Table 5 (3)
	xtivreg2 Dl_hpi (Dl_lir_b  = Linter_bra) LDl_hpi  $D_control_hp yr* [aw=w1], fe r bw(3) partial(yr*)  first
	avar_replicated Dl_lir_b 110
