function results = simulation(s,k,specid,beta_null,pi,delta,Sigma_pi,Sigma_delta,Sigma_delta_pi,zz,eff_f_crit)
disp(specid)
%% simulate pi and delta

rng(6);  % For reproducibility
 
delta_tilde  = beta_null*pi; % adjust delta so that the 2sls estimate beta is beta_null

mu = [delta_tilde,pi];
Sigma = [Sigma_delta, Sigma_delta_pi ; Sigma_delta_pi', Sigma_pi];

if k > 1 
    Sigma_zv = zz*Sigma_pi;
    initial_eff_f= pi*zz*pi'/trace(Sigma_zv);
else  
    initial_eff_f=pi*Sigma_pi^-1*pi';
end    
 

%%  calculate first stage effective f based on draws
    R = mvnrnd(mu, Sigma,s);
    pi_s = R(:,(k+1):2*k);

if k > 1 
    first_eff_f = diag(pi_s*zz*pi_s')/trace(Sigma_zv);

else  
    first_eff_f = diag(pi_s*Sigma_pi^-1*pi_s');
end    
 
if k > 1 
     eff_k_5 = round( (trace(Sigma_zv)^2*(1+2*5))/(trace(Sigma_zv*Sigma_zv)+2*5*trace(Sigma_zv)*eigs(Sigma_zv,1)));
     eff_k_10 =round( (trace(Sigma_zv)^2*(1+2*10))/(trace(Sigma_zv*Sigma_zv)+2*10*trace(Sigma_zv)*eigs(Sigma_zv,1)));

else  
     eff_k_5 = 1;
     eff_k_10 = 1;
end 

if eff_k_5 < 30
    eff_f_crit_5=eff_f_crit((eff_f_crit(:,1)==eff_k_5),3);
else
    eff_f_crit_5=eff_f_crit((eff_f_crit(:,1)==30),3);
end

if eff_k_10 < 30
    eff_f_crit_10=eff_f_crit((eff_f_crit(:,1)==eff_k_10),4);
else
    eff_f_crit_10=eff_f_crit((eff_f_crit(:,1)==30),4);
end
    first_f = diag(pi_s*Sigma_pi^-1*pi_s')/k;

    %%  calculate beta, variance of beta (by MD method)

    delta_s = R(:,1:k);
    beta_s = diag(pi_s*zz*pi_s').^-1.*diag(pi_s*zz*delta_s'); 

    nabla=[(diag(pi_s*zz*pi_s').^-1*ones(1,k)).*(pi_s*zz) ,  -(diag(pi_s*zz*pi_s').^-2*ones(1,k)).*(diag(pi_s*zz*delta_s')*ones(1,k)).*(pi_s*zz)];
 
    Sigma_beta_s = diag(nabla*Sigma*nabla');

    %% simulat t statistic and AR statistic
    t = (beta_s-beta_null) ./(Sigma_beta_s.^0.5);  
    ar = diag((delta_s-pi_s*beta_null)*inv(Sigma_delta-beta_null*Sigma_delta_pi-beta_null*Sigma_delta_pi'+beta_null^2*Sigma_pi)*(delta_s-pi_s*beta_null)');

    %% calculate sizes for t test
    j0=sum(abs(t)>1.64)/s; % 10% level
    q0=sum(abs(t)>1.96)/s; % 5% level
    l0=sum(abs(t)>2.58)/s; % 1% level

    %% calculate sizes for screening on the first-stage F
    a0=sum(abs(t(first_f>10))>1.64)/sum(first_f>10); % 10% level
    b0=sum(abs(t(first_f>10))>1.96)/sum(first_f>10); % 5% level
    c0=sum(abs(t(first_f>10))>2.58)/sum(first_f>10); % 1% level

    %% calculate sizes for two-step test
    d0=(sum(abs(t(first_f>10))>1.64) + sum(ar(first_f<=10)>chi2inv(0.9,k)))/s;
    e0=(sum(abs(t(first_f>10))>1.96) + sum(ar(first_f<=10)>chi2inv(0.95,k)))/s;
    f0=(sum(abs(t(first_f>10))>2.58) + sum(ar(first_f<=10)>chi2inv(0.99,k)))/s;

    %% calculate sizes for ar test
    m0=sum(ar >chi2inv(0.9,k))/s;
    n0=sum(ar >chi2inv(0.95,k))/s;
    o0=sum(ar >chi2inv(0.99,k))/s;

    %% frequency with which F>10 and mean F
    g0=sum(first_f>10)/s;
    r0 = mean(first_f);
    %% median bias of beta_s and t stat
    h0=median(beta_s)-beta_null;
    u0=median(t);
    %% initial first-stage F

    i0=pi*Sigma_pi^-1*pi'/k;
    %% calculate sizes for screening on the first-stage F and cutoff 10 
 
    t_post_eff_F10=mean(abs(t(first_eff_f>10))>1.96);  
   

    %% calculate sizes for two-step test and cutoff (5,10,15,25,crit5,crit10)
    twostep_eff_F5=(sum(abs(t(first_eff_f>5))>1.96) +...
                    sum(ar(first_eff_f<5)>chi2inv(0.95,k)))/s;
    twostep_eff_F10=(sum(abs(t(first_eff_f>10))>1.96) +...
                    sum(ar(first_eff_f<10)>chi2inv(0.95,k)))/s;
    twostep_eff_F15=(sum(abs(t(first_eff_f>15))>1.96) +...
                    sum(ar(first_eff_f<15)>chi2inv(0.95,k)))/s;
    twostep_eff_F20=(sum(abs(t(first_eff_f>20))>1.96) +...
                    sum(ar(first_eff_f<20)>chi2inv(0.95,k)))/s;

    twostep_eff_F_crit5=(sum(abs(t(first_eff_f>eff_f_crit_5))>1.96) +...
                        sum(ar(first_eff_f<eff_f_crit_5)>chi2inv(0.95,k)))/s;
    twostep_eff_F_crit10=(sum(abs(t(first_eff_f>eff_f_crit_10))>1.96) +...
                        sum(ar(first_eff_f<eff_f_crit_10)>chi2inv(0.95,k)))/s;

 
    %% output results
matname=strcat('./simulation_eff_F/spec', specid);
save(matname,'k','specid','beta_null','mu','Sigma','Sigma_pi','Sigma_delta','Sigma_delta_pi','zz','j0','q0','l0','a0','b0','c0','d0','e0','f0','m0','n0','o0','g0','r0','h0','u0','i0',...
    't_post_eff_F10','twostep_eff_F5','twostep_eff_F10','twostep_eff_F15','twostep_eff_F20',...
   'twostep_eff_F_crit5','twostep_eff_F_crit10','first_eff_f','eff_k_5','eff_k_10','initial_eff_f','-append');
end
